
* ----------------------------------------------------------------------
      subroutine baastp (j, l, is, jhold, ehold, ishold, nlevel, nlevop,
     :                  etemp, fjtemp, fktemp, fistmp,
     :                  rcut, jtot, flaghf, flagsu,
     :                  csflag, clist, bastst, ihomo, nu, numin, jlpar,
     :                  n, nmax, ntop)
* --------------------------------------------------------------------
*  subroutine to determine angular coupling potential for collision
*  of an asymmetric top molecule with a structureless atom or with an
*  uncorrugated surface
*  author:  paul dagdigian
*  current revision date:  15-sep-2009 by pjd
*  latest revisions:  16-sep-2009 by mha
* --------------------------------------------------------------------
*  variables in call list:
*    j:        on return contains rotational quantum number for each
*              channel
*    l:        on return contains orbital angular momentum for each
*              channel
*    is:       on return contains symmetry index (ieps * kp) for each
*              channel
*  Note that we have adopted the following convention for the symmetry
*  index "is" so that on return is = 0/1, with the symmetric top basis
*  functions written as [|j,kp> + (-1)^is*|j,-kp)\, respectively.
*    jhold:    on return contains rotational quantum numbers for each
*              rotational level
*    ehold:    on return contains energy in hartrees of each rotational
*              level
*    ishold:   on return contains symmetry index of each energetically
*              distinct level
*    nlevel:   on return contains number of energetically distinct
*              rotational levels used in channel basis
*    nlevop:   on return contains number of energetically distinct
*              rotational levels used in channel basis which are open
*              asymptotically
*    etemp:    scratch array used to create channel list
*    fjtemp:   scratch array used to create channel list
*    fktemp:   scratch array used to create channel list
*    fistmp:   scratch array used to create channel list
*    rcut:     cut-off point for keeping higher energy channels
*              if any open channel is still closed at r=rcut, then
*              all closed channels as well any open channels which are
*              still closed at r=rcut are dropped from basis
*              note that this is ignored in molecule-surface collisions!!!
*    jtot:     total angular momentum
*              in cc calculation jtot is the total angular momentum
*              in cs calculation jtot is the l-bar quantum number
*    flaghf:   if .true., then system has half-integer spin
*              if .false., then system has integer spin
*    flagsu:   if .true., then molecule-surface collisons
*    csflag:   if .true., then coupled-states calculation
*              if .false., the close-coupled calculation
*    clist:    if .true., then quantum numbers and energies listed for
*              each channel
*    bastst:   if .true., then execution terminates after the first call
*              to basis
*    ihomo:    if .true., then the molecule posseses interchange symmetry
*              (e.g. H2O, CH2, H2CO), so that only the ortho or para levels will be
*              included depending on the value of the parameter iop in common
*              /cosysi/ (see below)
*              subroutine currently to allow only BA2 or A2BC type molecules,
*              where the a inertial axis is an axis of C2 symmetry.
*    nu:       coupled-states projection index
*    numin:    minimum coupled states projection index
*              for cc calculations nu and numin are both set = 0 by calling
*              program
*    jlpar:    total parity of included channels in cc calculation
*              only those channels are included for which
*                  (-1)**(is+j+kp+l-jtot)=jlpar
*              where parity designates the parity of the molecular state
*              in cs calculation jlpar is set equal to 1 in calling program
*    n:        on return equals number of channels
*    nmax:     maximum dimension of arrays
*    ntop:     maximum row dimension of all matrices passed to subroutines
*              propag and soutpt.  ntop is set in basis only if nu = numin
*              otherwise it is unchanged from the value supplied by the
*              calling program
*  variables in common bloc /cosysr/
*    isrcod:   total number of real system dependent variables
*    arot:     A rotational constant for the asymmetric top
*    brot:     B rotational constant for the asymmetric top
*    crot:     C rotational constant for the asymmetric top
*    emax:     the maximum rotational energy (in cm^-1) for a channel to be
*              included in the basis
*  variables in common block /cosysi/
*    nscode:   total number of variable names which are passed to HINPUT
*              nscod must equal isrcod + isicod + 3
*    isicod:   total number of integer system dependent variables
*    nterm:    number of different associated legendre terms in
*              expansion of potential
*    numpot:   the number of the potential used, this variable is passed
*              to the pot subroutine
*    ipotsy:   cylindrical symmetry of potential.  Use this parm to
*              distinguish between BA2 and ABC type triatomics
*              set ipotsy = 2 and 1, respectively, for these types of
*              molecules
*    iop:      ortho/para label for molecular states. If ihomo=.true. then only
*              para states will be included if iop=1 and only ortho states if
*              iop=-1
*    jmax:     the maximum rotational angular momentum for the asymmetric top
*  variable in common block /cocent/
*    cent:      array containing centrifugal barrier of each channel
*  variable in common block /coeint/
*    eint:      array containing channel energies (in hartree)
*               the zero of energy is assumed to be the 0(0,0) level
*  variables in common block /coered/
*    ered:      collision energy in atomic units (hartrees)
*    rmu:       collision reduced mass in atomic units
*               (mass of electron = 1)
*  variables in common block /conlam/
*    nlam:      the number of angular coupling terms actually used
*    nlammx:    the maximum number of angular coupling terms
*    lamnum:    number of non-zero v2 matrix elements for each lambda
*               lamnum is an array of dimension nlammx
*  variables in common block /cov2/
*    nv2max:    maximum core memory allocated for the v2 matrix
*    v2:        lower triangle of nonzero angular coupling matrix elements
*               stored in packed column form that is (1,1), (2,1), (3,1) ...
*               (n,1), (2,2), (3,2) ... (n,2), etc.
*  variable in common block /coiv2/
*   iv2:        row+column index of v2 matrix for each non-zero element
*  variables in common block /coconv/
*   econv:      conversion factor from cm-1 to hartrees
*   xmconv:     converson factor from amu to atomic units
*  variables in common block /coatpi/
*   narray:     maximum size of asymmetric top basis fn expansion
*               set to 12 in himain (suitable for j  40)
*   isiz:       length of eigenfunction expansion for each rot. level
*  variable in common block /coatp3/
*   isizh:      temporary storage for length (related to isiz)
*  variable in common block /coatpr/
*   c:          expansion coefficients for asymmetric top rotor wave fns.
*               in a symmetrized symmetric top basis.  these basis functions
*               are given by green, jcp 64, 3463 (1976) as:
*                  |j,k,m,s> = [2*(1+delta(k,0)]^-1 *
*                      (|j,k,m> + (-1)*s * |j,-k,m>)
*               (note that green uses eps = (-1)*s for the symmetry index.)
*               in this basis, the asymmetric top hamiltonian block diagonalizes
*               into 4 groups:  (1) k even, s = +1, (2) k even, s= -1,
*               (3) k odd, s = =1, and (4) k odd, s = _1.
*               the expansion coefficients stored in the array c are:
*               c(k=0), c(k=2), ... c(k=j) for even k, and
*               c(k=1), c(k=3), ... c(k=j) for odd k.
*               the levels are denoted in the channel list by j and the
*               symmetry index is.  the prolate-limit projection quantum number kp
*               equals abs(is), and s is the sign of is.  the oblate limit projection
*               quantum number ko can be obtained as follows:
*                  if is  0, then ko = j - kp
*                  if is < 0, then ko = j + 1 - kp
*               if bastst=t, the values of j, is, kp, and ko are printed out, as
*               well as the values of the expansion coefficients
*  variable in common block /coatp1/
*   ctemp:      temporary storage for rot. e.fn coeffs.
*  variable in common block /coatp2/
*   chold:      ditto
*  subroutines called:
*   vlmatp:     returns angular coupling coefficient for particular
*               choice of channel index
*   prmatp:     computes primitive cc and cs v-lambda matrix elements
*               between symmetric top basis fns.
*   rotham:     computes matrix elements of asymmetric top hamiltonian
* --------------------------------------------------------------------
      implicit double precision (a-h,o-z)
      logical flaghf, csflag, clist, flagsu, ihomo, bastst
      character*1 slab
      include "common/parbas"
      include "common/parbasl"
      common /cosysi/ nscode, isicod, nterm, numpot, ipotsy, iop, jmax
      common /coipar/ iiipar(9), iprint
      common /cosysr/ isrcod, junkr, arot, brot, crot, emax
      common /cov2/ nv2max, junkv, v2(1)
      common /coiv2/ iv2(1)
      common /conlam/ nlam, nlammx, lamnum(1)
      common /cocent/ cent(1)
      common /coeint/ eint(1)
      common /coered/ ered, rmu
      common /coconv/ econv, xmconv
      common /coatpi/ narray, isiz(1)
      common /coatp3/ isizh(1)
      common /coatpr/ c(1)
      common /coatp1/ ctemp(1)
      common /coatp2/ chold(1)
      dimension j(1), l(1), is(1), jhold(1), ehold(1),
     :          ishold(1), etemp(1), fjtemp(1), fktemp(1),
     :          fistmp(1), nlami(4)
*  scratch arrays for computing asymmetric top energies and wave fns.
      dimension e(narray,narray), eig(narray), vec(narray,narray),
     :  sc1(narray), sc2(narray), work(288)
*
      zero = 0.d0
      two = 2.d0
*  check for consistency in the values of flaghf and csflag
      if (flaghf) then
        write (6, 5)
        write (9, 5)
5      format (' *** FLAGHF = .TRUE. FOR SINGLET SYSTEM; ABORT ***')
        stop
      end if
      if (flagsu .and. .not. csflag) then
        write (6, 6)
        write (9, 6)
6     format
     :   ('  *** CSFLAG = .FALSE. FOR SURFACE CALCULATION; ABORT ***')
        stop
      end if
      if (flagsu) then
        write (6, 10)
        write (9, 10)
10      format ('  *** FLAGSU = .TRUE. FOR ASYMMETRIC TOP',
     :     ' COLLISIONS; NOT IMPLEMENTED.  ABORT ***')
        call exit
      end if
      xjtot = jtot
      nsum = 0
      do 35  i = 1, nterm
        if (mproj(i) .gt. lammin(i) ) then
          write (6, 30) mproj(i), lammin(i), i
          write (9, 30) mproj(i), lammin(i), i
30        format (' *** MPROJ=',i2,' > LAMMIN=',i2,
     :            ' FOR TERM',i2,'; ABORT ***')
          stop
        end if
        lmin = lammin(i)
        lmax = lammax(i)
        nlami(i) = 0
        do lb = lmin, lmax, ipotsy
          nlami(i) = nlami(i) + 1
        end do
        nsum = nsum + nlami(i)
35    continue
      if (nlammx .lt. nsum) then
        write (6, 40) nsum, nlammx
        write (9, 40) nsum, nlammx
40      format (' ** TOTAL NUMBER OF ANISOTROPIC TERMS=', i2,
     :          ' .GT. NLAMMX=', i2,'; ABORT')
        stop
      end if
      if (nsum .ne. nlam) then
        write (6, 45) nsum, nlam
        write (9, 45) nsum, nlam
45      format (' *** NLAM IN BASIS=', i3,' .NE. NLAM FROM SYSDAT=',
     :           i3, '; ABORT ***')
        stop
      end if
      if (bastst) write (6, 46) nsum
      write (9, 46) nsum
46    format (' ** TOTAL NUMBER OF ANISTROPIC TERMS IN POTENTIAL =',
     :        i3)
      nlam = nsum
      if (clist) then
        if (csflag) then
          if (ihomo) then
            if (bastst) then
              write (6,65) rmu * xmconv, arot, brot, crot,
     :             ipotsy, iop, ered * econv, jtot, nu
            end if
            write (9,65) rmu * xmconv, arot, brot, crot,
     :             ipotsy, iop,ered * econv, jtot, nu
65          format(/,' **  CS ASYMMETRIC TOP **',
     :        /,'     RMU=', f9.4,'  AROT=', f7.3,'  BROT=',
     :        f7.3,/,'  CROT=',f7.3,/,'     POT-SYM=', i2,
     :       '  O/P=',i2,'  E=', f7.2,'  LBAR=', i5, 2x,' NU=', i3)
          else
            if (bastst) then
              write (6,75) rmu * xmconv, arot, brot, crot,
     :              ipotsy, ered * econv, jtot, nu
            end if
            write (9,75) rmu * xmconv, arot, brot, crot,
     :              ipotsy, ered * econv, jtot, nu
75          format(/,' **  CS ASYMMETRIC TOP **',
     :        /,'     RMU=', f9.4,'  AROT=', f7.3,'  BROT=',
     :        '  CROT=',f7.3,/,'     POT-SYM=', i2,
     :        '     E=', f7.2,'  LBAR=', i5, 2x,' NU=', i3)
          end if
        else
          if (ihomo) then
            if (bastst) then
              write (6,80) rmu * xmconv, arot, brot, crot, ipotsy,
     :             iop, ered * econv, jtot, jlpar
            end if
            write (9,80) rmu * xmconv, arot, brot, crot, ipotsy,
     :              iop, ered * econv, jtot, jlpar
80          format(/,' **  CC ASYMMETRIC TOP **',
     :        /,'     RMU=', f9.4,'  AROT=', f7.3, '  BROT=',f7.3,
     :        '  CROT=',f7.3,/, '     POT-SYM=', i2,'  O/P=',i2,
     :        '  E=', f7.2, '  JTOT=', i4, 2x,' JLPAR=', i2)
          else
            if (bastst) then
              write (6,85) rmu * xmconv, arot, brot, crot,
     :             ered * econv, jtot, jlpar
            end if
            write (9,85) rmu * xmconv, arot, brot, crot,
     :             ered * econv, jtot, jlpar
85          format(/,' **  CC ASYMMETRIC TOP **',
     :        /,'     RMU=', f9.4,'  AROT=', f7.3, '  BROT=',f7.3,
     :       '  CROT=',f7.3,/,  '     E=', f7.2, '  JTOT=', i4, 2x,
     :        ' JLPAR=', i2)
          end if
        end if
        if (.not. flagsu) write (9,90) rcut
90      format (/' OPEN CHANNELS ELIMINATED WHICH ARE CLOSED AT R=',
     :          f6.2)
      end if
*  first set up list of all j(kp,ko) states included in basis
      nlist = 0
      do ji = 0, jmax
* set up and diagonalize rotational hamiltonian for each value of ji
* hamiltonian block diagonalize into 1-4 subblocks
*
* E+ submatrix
        isize = (ji + 2)/2
        do mm = 1, isize
          do nn = 1, isize
            e(mm,nn) = 0.d0
          end do
        end do
        e(1,1) = rotham(ji,0,ji,0)
        if (isize .gt. 1) then
          do mm = 2, isize
            kk = 2*mm - 2
            e(mm,mm) = rotham(ji, kk, ji, kk)
            e(mm,mm-1) = rotham(ji,kk,ji,kk-2)
            e(mm-1,mm) = e(mm,mm-1)
          end do
          e(2,1) = sqrt(2.d0)*e(2,1)
          e(1,2) = e(2,1)
        end if
cstart unix-darwin .or. unix-86
        lwork = 144
        call dsyev('V','L',isize,e,narray,eig,work,lwork,ierr)
cend
cstart .not. unix-darwin .and. .not. unix-86
c;      write (6,1225)
c;1225    format('  *** DSYEV NOT ACCESSIBLE IN THIS VERSION OF CODE.')
c;        call exit
cend
        do mm = 1, isize
          nlist = nlist + 1
*  eigenvalues stored in order of increasing energy (lowest KP first)
          etemp(nlist) = eig(mm)
          fjtemp(nlist) = ji
          fktemp(nlist) = 2*mm - 2
          fistmp(nlist) = 1
*  eigenfunctions expressed over basis KP = 0, 2, 4, ...
          nbas = int(fktemp(nlist)/2) + 1
          do nn = 1, isize
            isub = (nlist - 1)*narray + nn
*  make sure coeff for prolate k is positive
            if (e(mm, nbas) .gt. zero) then
              ctemp(isub) = e(mm, nn)
            else
              ctemp(isub) = -e(mm, nn)
            end if
          end do
        end do
*
* E- submatrix
        isize = ji/2
        if (isize .gt. 0) then
          do mm = 1, isize
            do nn = 1, isize
              e(mm,nn) = 0.d0
            end do
          end do
          e(1,1) = rotham(ji,2,ji,2)
          if (isize .gt. 1) then
          do mm = 2, isize
            kk = 2*mm
            e(mm,mm) = rotham(ji, kk, ji, kk)
            e(mm,mm-1) = rotham(ji,kk,ji,kk-2)
            e(mm-1,mm) = e(mm,mm-1)
          end do
          end if
          call dsyev('V','L',isize,e,narray,eig,work,lwork,ierr)
          do mm = 1, isize
            nlist = nlist + 1
*  eigenvalues stored in order of increasing energy (lowest KP first)
            etemp(nlist) = eig(mm)
            fjtemp(nlist) = ji
            fktemp(nlist) =  2*mm
            fistmp(nlist) = -1
*  eigenfunctions expressed over basis KP = 0, 2, 4, ...
            nbas = int(fktemp(nlist)/2)
            do nn = 1, isize
              isub = (nlist - 1)*narray + nn
*  make sure coeff for prolate k is positive
              if (e(mm, nbas) .gt. zero) then
                ctemp(isub) = e(mm, nn)
              else
                ctemp(isub) = -e(mm, nn)
              end if
            end do
          end do
        end if
*
* O+ submatrix
        isize = (ji + 1)/2
        if (isize .gt. 0) then
          do mm = 1, isize
            do nn = 1, isize
              e(mm,nn) = 0.d0
            end do
          end do
          e(1,1) = rotham(ji,1,ji,1) + rotham(ji,1,ji,-1)
          if (isize .gt. 1) then
          do mm = 2, isize
            kk = 2*mm - 1
            e(mm,mm) = rotham(ji, kk, ji, kk)
            e(mm,mm-1) = rotham(ji,kk,ji,kk-2)
            e(mm-1,mm) = e(mm,mm-1)
          end do
          end if
          call dsyev('V','L',isize,e,narray,eig,work,lwork,ierr)
          do mm = 1, isize
            nlist = nlist + 1
*  eigenvalues stored in order of increasing energy (lowest KP first)
            etemp(nlist) = eig(mm)
            fjtemp(nlist) = ji
            fktemp(nlist) =  2*mm - 1
            fistmp(nlist) = 1
*  eigenfunctions expressed over basis KP = 1, 3, 5, ...
            nbas = int((fktemp(nlist) - 1)/2) + 1
            do nn = 1, isize
              isub = (nlist - 1)*narray + nn
*  make sure coeff for prolate k is positive
              if (e(mm, nbas) .gt. zero) then
                ctemp(isub) = e(mm, nn)
              else
                ctemp(isub) = -e(mm, nn)
              end if
            end do
          end do
        end if
*
* O- submatrix
        isize = (ji + 1)/2
        if (isize .gt. 0) then
          do mm = 1, isize
            do nn = 1, isize
              e(mm,nn) = 0.d0
            end do
          end do
          e(1,1) = rotham(ji,1,ji,1) - rotham(ji,1,ji,-1)
          if (isize .gt. 1) then
          do mm = 2, isize
            kk = 2*mm - 1
            e(mm,mm) = rotham(ji, kk, ji, kk)
            e(mm,mm-1) = rotham(ji,kk,ji,kk-2)
            e(mm-1,mm) = e(mm,mm-1)
          end do
          end if
          call dsyev('V','L',isize,e,narray,eig,work,lwork,ierr)
          do mm = 1, isize
            nlist = nlist + 1
*  eigenvalues stored in order of increasing energy (lowest KP first)
            etemp(nlist) = eig(mm)
            fjtemp(nlist) = ji
            fktemp(nlist) =  2*mm - 1
            fistmp(nlist) = -1
*  eigenfunctions expressed over basis KP = 1, 3, 5, ...
            nbas = int((fktemp(nlist) - 1)/2) + 1
            do nn = 1, isize
              isub = (nlist - 1)*narray + nn
*  make sure coeff for prolate k is positive
              if (e(mm, nbas) .gt. zero) then
                ctemp(isub) = e(mm, nn)
              else
                ctemp(isub) = -e(mm, nn)
              end if
            end do
          end do
        end if
      end do
*
*  now sort this list in terms of increasing energy
      if (nlist .gt. 1) then
        do 120 i1 = 1, nlist - 1
          esave = etemp(i1)
          do 115 i2 = i1 + 1, nlist
            if (etemp(i2) .lt. esave) then
*  state i2 has a lower energy than state i1, switch them
              esave = etemp(i2)
              etemp(i2) = etemp(i1)
              etemp(i1) = esave
              fjsave = fjtemp(i2)
              fjtemp(i2) = fjtemp(i1)
              fjtemp(i1) = fjsave
              fksave = fktemp(i2)
              fktemp(i2) = fktemp(i1)
              fktemp(i1) = fksave
              fissav = fistmp(i2)
              fistmp(i2) = fistmp(i1)
              fistmp(i1) = fissav
*  also move e.fn coeffs (don't worry about size of e.fn)
              do mm = 1, narray
                isub1 = (i1 - 1)*narray + mm
                isub2 = (i2 - 1)*narray + mm
                sc1(mm) = ctemp(isub2)
                ctemp(isub2) = ctemp(isub1)
                ctemp(isub1) = sc1(mm)
              end do
            end if
115       continue
120     continue
      end if
*
*  now set up channel and level list
*  print this list if bastst = .true. or if clist = .true.
      if (bastst .or. clist) then
        write (6, 130)
130     format (/,2x,
     :   'LEVEL LIST SORTED BY ENERGY',/,'   N   J  ',
     :     'IS  KP  KO  S   EINT(CM-1)  COEFFS')
      end if
      n = 0
      nlevel = 0
      do 170  njk = 1, nlist
        ki = fktemp(njk)
        ji = fjtemp(njk)
        isi = fistmp(njk)
*
*  delete state if energy > emax
        if (etemp(njk) .gt. emax) go to 170
*
        if (ihomo) then
*  check to see if (ki/isi) corresponds to an allowed ortho/para level for
*  a symmetric molecule.  the statements below correspond to BA2 and A2BC
*  type molecules like H2O, CH2, and H2CO
          if (isi .eq. 1) then
            iss = 0
          else
            iss = 1
          end if
          iph = ji + ki + iss
          if (ki .ne. 2*(ki/2)) iph = iph + 1
          iexsym = (-1) ** iph
          if (iexsym .ne. iop) go to 170
        end if
*  here if this state is to be included
        nlevel = nlevel + 1
        ehold(nlevel) = etemp(njk) / econv
        jhold(nlevel) = ji
        ishold(nlevel) = isi * ki
*  also move e.fn coeffs
        do mm = 1, narray
          isub = (nlevel - 1)*narray + mm
          isub1 = (njk - 1)*narray + mm
          chold(isub) = ctemp(isub1)
        end do
*
*  print this level if bastst = .true.
*  determine size of wave function expansion for printout
        if (ki .eq. 2*(ki/2)) then
          if (isi .eq. 1) then
*  E+ block
            isize = (ji + 2)/2
          else
*  E- block
            isize = ji/2
         end if
        else
*  O+, O- blocks
            isize = (ji + 1)/2
        end if
        isizh(nlevel) = isize
        if (bastst .or. clist) then
          ecm = ehold(nlevel) * econv
          isub = (nlevel - 1)*narray
          if (isi.eq.1) then
            slab='+'
          else
            slab='-'
          endif
*  compute kp and ko projection quantum numbers
          kp = abs(ishold(nlevel))
          if (ishold(nlevel) .ge. 0) then
            ko = jhold(nlevel) - kp
          else
            ko = jhold(nlevel) + 1 - kp
          end if
          if (isize .gt. 6) then
            write (6, 135) nlevel, jhold(nlevel), ishold(nlevel),
     :        kp, ko, slab, ecm, (chold(isub + mm), mm=1,isize)
135         format (5i4, a3, f10.3, 3x, 6f8.4/36x, 6f8.4)
          else
            write (6, 1351) nlevel, jhold(nlevel), ishold(nlevel),
     :        kp, ko, slab, ecm, (chold(isub + mm), mm=1,isize)
1351         format (5i4, a3, f10.3, 3x, 6f8.4)
          end if
        end if
*
*  here for cs calculations; include state only if j at least equal to coupled
*  states projection index
        if (csflag) then
          if (ji .ge. nu) then
            n = n + 1
            if (n .gt. nmax) then
              write (6, 150) n, nmax
              write (9, 150) n, nmax
150           format(/' *** NCHANNELS=', i5,
     :             ' .GT. MAX DIMENSION OF',i5,' ABORT ***')
              stop
            end if
            is(n) = ishold(nlevel)
            j(n) = ji
            eint(n) = ehold(nlevel)
            l(n) = jtot
            cent(n) = jtot * (jtot + 1)
*  move e.fn also
            isiz(n) = isizh(nlevel)
            do mm = 1, narray
              isub = (n - 1)*narray + mm
              isub1 = (nlevel - 1)*narray + mm
              c(isub) = chold(isub1)
            end do
          end if
        else if (.not. csflag) then
*
*  here for cc calculations.  first calculate range of orbital angular
*  momentum quantum numbers allowed for this state
*  determine parity of molecular state [Eq. (A21) of S. Green, J. Chem. Phys.
*  73, 2740 (1980) and Townes and Schawlow, Microwave Spectroscopy, Eq. (3-27),
*  p. 64.]  See Eq. (A3) of Green.
          iss = sign(1, ishold(nlevel))
          ipar = (-1) ** (ji + ki) * iss
          lmax = jtot + ji
          lmin = iabs (jtot - ji)
          do 155  li = lmin, lmax
            ix = ipar * (-1) ** (li - jtot)
*  original defn
*            lpar = (-1) ** (li - jtot)
*
*  check to see if this channel has the desired parity, if so, include it
*  original defn
*            if (ipar * lpar .eq. jlpar) then
*
            if (ix .eq. jlpar) then

              n = n + 1
              if (n .gt. nmax) then
                write (6, 150) n, nmax
                write (9, 150) n, nmax
                stop
              end if
              is(n) = ishold(nlevel)
              j(n) = ji
              eint(n) = ehold(nlevel)
              l(n) = li
              cent(n) = li * (li + 1)
*  move e.fn also
              isiz(n) = isizh(nlevel)
              do mm = 1, narray
                isub = (n - 1)*narray + mm
                isub1 = (nlevel - 1)*narray + mm
                c(isub) = chold(isub1)
              end do
            end if
155       continue
        end if
170   continue
*
*  also determine number of levels which are open
      nlevop = 0
      do 250  i = 1, nlevel
        if (ehold(i) .le. ered) then
          nlevop = nlevop + 1
        end if
250   continue
*  now check to see if any of the open channels are closed at r=rcut
*  this is not done for molecule-surface collisions or for rcut < 0
      if (.not.flagsu .and. rcut .gt. 0.d0 .and. .not.boundc) then
        emin = 1. e+7
        do 290  i = 1, n
          if (eint(i) .le. ered) then
*  here if channel is open asymptotically
            if ( jtot * (jtot + 1) / (two * rmu * rcut * rcut)
     :          .gt. (ered - eint(i)) ) then
*  here if channel is open asymptotically but closed at r = rcut
              if (eint(i) .lt. emin) emin = eint(i)
*  emin now contains the lowest channel energy for which this condition is met
            end if
          end if
290     continue
*  now eliminate all channels with eint .ge. emin if any of the channels
*  are open asymptotically but closed at r = rcut
        if (emin.lt.ered) then
          nn = 0
          do 300 i = 1, n
            if (eint(i) .lt. emin) then
*  here if this channel is to be included
              nn = nn + 1
              eint(nn) = eint(i)
              j(nn) = j(i)
              is(nn) = is(i)
              cent(nn) = cent(i)
              l(nn) = l(i)
              isiz(nn) = isiz(i)
              do mm = 1, narray
                isub = (nn - 1)*narray + mm
                isub1 = (i - 1)*narray + mm
                c(isub) = c(isub1)
              end do
            end if
300       continue
*  reset number of channels
          n = nn
        end if
      end if
*  return if no channels
      if (n .eq. 0) return
      if (nu .eq. numin) then
        ntop = max(n, nlevop)
*  ntop is the maximum row dimension of all matrices passed in the
*  call list of subroutines propag and soutpt.
*  for fps make sure this is an odd number, for faster bank access.
*  this has no effect on vax or cray
        if (mod(ntop,2) .eq. 0 .and. ntop .lt. nmax)
     :       ntop = ntop + 1
      else
        if (n.gt.ntop) then
          write (6, 303) nu, n, ntop
          write (9, 303) nu, n, ntop
303       format (' *** NCH = ',i3, ' AT NU = ',i2, ' .GT. NTOP = ',i3,
     :            '; ABORT **',/,
     :    '     CHECK RCUT')
          call exit
        endif
      end if
*  now list channels if requested
      if (clist) then
        if (.not.csflag) then
          if (bastst .or. clist) write (6, 305)
          write (9,305)
305       format
     :    (/,2x,'CHANNEL LIST SORTED BY ENERGY',/,
     :     '   N   J  IS   L   EINT(CM-1)  COEFFS')
        else
          if (bastst .or. clist) write (6, 310) nu
          write (9,310) nu
310       format
     :     (/,2x,'CHANNEL LIST SORTED BY ENERGY',/,
     :     '   N   J  IS   L   EINT(CM-1) ** NU = ',i2)
        end if
        do 330  i = 1, n
          ecm = eint(i) * econv
          if (bastst .or. clist) then
            isize = isiz(i)
            isub = (i - 1)*narray
             if (isize .gt. 6) then
             write (6, 320) i, j(i), is(i), l(i), ecm,
     :          (c(isub + mm), mm=1,isize)
              write (9, 320) i, j(i), is(i), l(i), ecm,
     :          (c(isub + mm), mm=1,isize)
320           format (4i4, f10.3, 3x, 6f8.4/29x, 6f8.4)
            else
              write (6, 3201) i, j(i), is(i), l(i), ecm,
     :          (c(isub + mm), mm=1,isize)
              write (9, 3201) i, j(i), is(i), l(i), ecm,
     :          (c(isub + mm), mm=1,isize)
3201          format (4i4, f10.3, 3x, 6f8.4)
            end if
          end if
330     continue
      end if
*
*  now calculate coupling matrix elements
*  i counts v2 elements
*  inum counts v2 elements for given lambda
*  ilam counts number of v2 matrices
*  ij is address of given v2 element in present v2 matrix
      i = 0
      if (bastst.and. iprint.ge. 2) then
        write (6, 340)
        write (9, 340)
340     format (/' ILAM  LAMBDA   MU    ICOL  IROW    I    IV2    VEE')
      end if
      lamsum = 0
      ilam = 0
      do 400 iterm = 1, nterm
        lbmin = lammin(iterm)
*  if bastst = .true., then get the matrix elements of the lb=0 term
*  in the potential
        if (bastst .and. iterm .eq. 1) lbmin = 0
        do 390 lb = lbmin, lammax(iterm), ipotsy
*  ilam is the index for the next term in the potential matrix
*  lb is the actual value of lambda
          ilam = ilam + 1
          mu = mproj(iterm)
          inum = 0
          ij = 0
          do 355  icol = 1, n
            do 350  irow = icol, n
              ij = ntop * (icol - 1) + irow
              lrow = l(irow)
              if (csflag) lrow = nu
              call vlmatp (j(irow), lrow, j(icol), l(icol), jtot,
     :                     is(irow), is(icol), lb, mu, vee,
     :                     csflag, irow, icol)

*  change check for nonzero v2 matrix element
*              if (vee .ne. zero) then
              if (abs(vee) .gt. 1.d-15) then

                i = i + 1
                if (i .le. nv2max) then
                  inum = inum + 1
                  v2(i) = vee
                  iv2(i) = ij
                  if (bastst.and. iprint.ge.2) then
                    write (6, 345) ilam, lb, mu, icol, irow, i, iv2(i),
     :                             vee
                    write (9, 345) ilam, lb, mu, icol, irow, i, iv2(i),
     :                             vee
345                 format (i4, 3i7, 2i6, i6, g17.8)
                  end if
                end if
              end if
350         continue
355       continue
          if (i .le. nv2max) lamnum(ilam) = inum
          if (bastst) then
            write (6, 370) ilam, lamnum(ilam)
            write (9, 370) ilam, lamnum(ilam)
370         format ('ILAM=',i3,' LAMNUM(ILAM) = ',i6)
          end if
          lamsum = lamsum + lamnum(ilam)
390     continue
400   continue
      if ( i.gt. nv2max) then
         write (6, 450) i, nv2max
         write (9, 450) i, nv2max
450      format (' *** NUMBER OF NONZERO V2 ELEMENTS = ',i6,
     :           ' .GT. NV2MAX=',i6,'; ABORT ***')
         stop
      end if
      if (clist .and. bastst) then
        write (6, 460) lamsum
        write (9, 460) lamsum
460     format (' ** TOTAL NUMBER OF NONZERO V2 MATRIX ELEMENTS IS ',
     :           i5)
      end if
      return
      end
* --------------------------------------------------------------------
      subroutine vlmatp (jp, lp, j, l, jtot, isp, is, lambda, mu,
     :                   v, csflag, indp, ind)
*  subroutine to calculate v-lambda matrices for close-coupled or coupled-states
*  treatment of collisions of an asymmetric top with an atom
*  the angular dependence of the (lambda,mu) term in the potential is given by
*          Y(lambda,mu) + (-1)^mu * Y(lambda,-mu)
*  the primitive cc and cs matrix elements are given in eqs. (26) and (32),
*  respectively, of s. green, j. chem. phys. 64, 3463 (1976)
*  the expressions for the full matrix elements for definite-parity symmetric
*  top wavefunctions are given in eqs. (46-48) and (50) of the same article.
*  note, that in this article the bra indices (left side of matrix elements)
*  are primed, while in the conventions of the present subroutine the bra
*  indices are primed and the ket indices (right-hand side of matrix elements),
*  unprimed.
*
*  author of vlmstp:  millard alexander
*  revised from vlmstp subr for asymmetric top levels by paul dagdigian
*  current revision date:  3-sep-2009 by pjd
*  -----------------------------------------------------------------------
*  variables in call list:
*    jp:       rotational quantum number of left side of matrix element (bra)
*    lp:       orbital angular momentum of left side of matrix element (bra)
*    j:        rotational quantum number of right side of matrix element (ket)
*    l:        orbital angular momentum of right side of matrix element (ket)
*    jtot:     total angular momentum
*    isp:      symmetry index of bra
*    is:       symmetry index of ket
*    lambda:   order of legendre term in expansion of potential
*    mu:       absolute value of index of legendre term in expansion of
*              potential
*    v:        on return, contains desired matrix element
*    csflag:   if .true., then cs calculation; in this case:
*                jtot in call list is cs lbar
*                lp is nu (cs projection index)
*                l is not used
*              if .false., then cc calculation; in this case:
*                jtot is total angular momentum and l and lp correspond
*                to the orbital angular momenta
*    indp:     number of left-side level in channel list
*    ind:      number of right-side level in channel list
*  variable in common block /coatpi/
*    narray:   maximum size of asymmetric top basis fn expansion
*              set to 12 in himain (suitable for j  40)
*  variable in common block /coatpr/
*    c:        expansion coefficients for asymmetric top rotor wave fns.
*  subroutines called:
*    xf3j, xf6j, prmatp
*  -----------------------------------------------------------------------
      implicit double precision (a-h,o-z)
      logical csflag
      common /coatpi/ narray
      common /coatpr/ c(1)
*
      data one, zero, two / 1.0d0, 0.0d0, 2.0d0 /
      v = zero
*  determine k_prolate and symmetry index of the asymmetric top wave functions
      kp = abs(isp)
      iepsp = sign(1, isp)
      k = abs(is)
      ieps = sign(1, is)
*  check phase relations first
      iphase = ieps * iepsp * (-1) ** (jp + j + lambda + mu)
      if (iphase .eq. -1) return
*  first determine size and symmetry block of wave function expansions
*  ket
      if (k .eq. 2*(k/2)) then
        if (ieps .eq. 1) then
*  E+ block
          isize = (j + 2)/2
          kmin = 0
        else
*  E- block
          isize = j/2
          kmin = 2
        end if
      else
*  O+, O- blocks
          isize = (j + 1)/2
          kmin = 1
      end if
*  bra
      if (kp .eq. 2*(kp/2)) then
        if (iepsp .eq. 1) then
*  E+ block
          isizp = (jp + 2)/2
          kminp = 0
        else
*  E- block
          isizp = jp/2
          kminp = 2
        end if
      else
*  O+,O- blocks
          isizp = (jp + 1)/2
          kminp = 1
      end if
*
      v = 0.d0
      do 100 mm = 1,isize
      do 100 nn = 1,isizp
        isubp = (indp - 1)*narray + nn
        isub = (ind - 1)*narray + mm
        kbas = kmin + (mm - 1)*2
        kbasp = kminp + (nn - 1)*2
        kdif = kbas - kbasp
        if (iabs(kdif) .eq. mu) then
          omeg = one
          if (csflag) then
*  the signed value of mu in the cs matrix elements is given by the
*  3j symbol (j' lambda j / -k' mu k) so that mu = k' - k = - kdif
            musign = - kdif
*  the multiplicative factor is given by Eq. (52) of S. Green, j. chem. phys.
*  64, 3463 (1976)
            if (kdif .gt. 0) omeg =  (-1) ** mu
          else if (.not. csflag) then
*  the signed value of mu in the cc matrix elements is given by the
*  3j symbol (j' j lambda / k' -k mu) so that mu = k - k'= kdif
            musign = kdif
*  the multiplicative factor is given by Eq. (48) of S. Green, j. chem. phys.
*  64, 3463 (1976)
            if (kdif .lt. 0)  omeg =  (-1) ** mu
          end if
*  contribution from (jp, kp, lp / Y(lambda, mu) / j, k, l), that is
*  the first term in Eq. (46) of S. Green, j. chem. phys. 64, 3463 (1976)
          call prmatp (jp, lp, j, l, jtot, kbasp, kbas, lambda, musign,
     :               vprm, csflag)
          v = v + omeg * vprm * c(isubp) * c(isub)
        end if
        if (kbas + kbasp .eq. mu) then
*  n.b. for kbas = 0 and/or kbasp = 0, we recompute the same primitive matrix
*  element (here we follow MOLSCAT, although this might be somewhat inefficient
*  this is the second term in Eq. (46) of S. Green, j. chem. phys. 64, 3463
          if (.not.csflag) then
*  cc contribution from (jp, -kp, lp / Y(lambda, mu) / j, k, l)
            call prmatp (jp, lp, j, l, jtot, -kbasp, kbas, lambda, mu,
     :                 vprm, csflag)
            v = v + vprm * iepsp * c(isubp) * c(isub)
          else if (csflag) then
*  cs contribution from (jp, kp, lp / Y(lambda, mu) / j, -k, l)
            call prmatp (jp, lp, j, l, jtot, kbasp, -kbas, lambda, mu,
     :                 vprm, csflag)
            v = v + vprm * ieps * c(isubp) * c(isub)
          end if
        end if
100   continue
      return
      end
* ----------------------------------------------------------------------
      subroutine prmatp (jp, lp, j, l, jtot, kp, k, lambda, mu,
     :                   vprm, csflag)
*  subroutine to calculate primitive v-lambda matrix elements for close-coupled
*  treatment of collisions of a symmetric top with an atom
*  the primitive cc and cs matrix elements are given in eqs. (26) and (32),
*  respectively, of s. green, j. chem. phys. 64, 3463 (1976)
*  note, that in this article the bra indices are unprimed and the ket indices
*  primed, while in the conventions of the present subroutine the bra indices
*  are primed and the ket indices, unprimed.
*
*  duplicate of prmstp
*  author:  millard alexander
*  current revision date:  27-mar-90
*  -----------------------------------------------------------------------
*  variables in call list:
*    jp:       rotational quantum number of left side of matrix element (bra)
*    lp:       orbital angular momentum of left side of matrix element (bra)
*    j:        rotational quantum number of right side of matrix element (ket)
*    l:        orbital angular momentum of right side of matrix element (ket)
*    jtot:     total angular momentum
*    kp:       k quantum number of bra
*    k:        k quantum number of ket
*    lambda:   order of legendre term in expansion of potential
*    mu:       index of legendre term in expansion of potential
*    vrpm:     on return, contains primitive matrix element
*    csflag:   if .true., then cs calculation; in this case:
*                jtot in call list is cs lbar
*                lp is nu (cs projection index)
*                l is not used
*              if .false., then cc calculation; in this case:
*                jtot is total angular momentum
*  subroutines called:
*     xf3j, xf6j
*  -----------------------------------------------------------------------
      implicit double precision (a-h,o-z)
      logical csflag
      data half, one, two, zero, four / 0.5d0, 1.d0, 2.d0, 0.d0, 4.d0/
      data pi /3.1415926536d0 /
      vprm = zero
      xjp = jp
      xj = j
      xkp = kp
      xk = k
      xjtot = jtot
      if (csflag) then
        nu = lp
        xnu = nu
      end if
      xlp = float(lp)
      xl = float(l)
      xlamda = float(lambda)
      xmu = float(mu)
      xnorm = (two * xjp + one) * (two * xj + one) *
     :        (two * lambda + one) / (four * pi)
*  special normalization for k and/or kp = 0
*  see Eq. (46) of S. Green, j. chem. phys. 64, 3463 (1976)
      if (k .eq. 0) xnorm = xnorm * half
      if (kp .eq. 0) xnorm = xnorm * half
*  the desired matrix element is constructed in x
      if (.not. csflag) then
*  here for cc matrix elements
        x = xf3j (xlp, xlamda, xl, zero, zero, zero)
        if (x .eq. zero) return
        x = x * xf3j (xjp, xj, xlamda, xkp, - xk, xmu)
        if (x .eq. zero) return
        x = x * xf6j (xj, xl, xjtot, xlp, xjp, xlamda)
        if (x .eq. zero) return
        iphase = jp + j + kp - jtot
        xnorm = xnorm * (two * lp + one) * (two * l + one)
      else if (csflag) then
*  here for cs matrix elements
        iphase = - k - nu
        x = xf3j (xjp, xlamda, xj, -xnu, zero, xnu)
        if (x .eq. zero) return
        x = x * xf3j (xjp, xlamda, xj, -xkp, xmu, xk)
      end if
      vprm = ( (-1) ** iphase) * x * sqrt(xnorm)
      return
      end
* ----------------------------------------------------------------------
      double precision function rotham(ji, ki, jf, kf)
*
*  subroutine to compute matrix elements of the asymmmetric top hamiltionian
*  in a prolate (case Ia) basis between unsymmetrized basis functions
*  (ji,ki) and (jf,kf)
*
*  author:  paul dagdigian
*  current revision date:  16-aug-2009
*  -----------------------------------------------------------------------
      implicit double precision (a-h,o-z)
      common /cosysr/ isrcod, junkr, arot, brot, crot, emax
      bpc = (brot + crot)*0.5d0
      bmc = (brot - crot)*0.25d0
      if (ji .ne. jf) goto 900
      fjj1 = ji*(ji + 1.d0)
      fk = ki
      if (ki .ne. kf) goto 10
*
*     diagonal term
      rotham = bpc*(fjj1 - fk**2) + arot*fk**2
      goto 1000
*
*     off-diagonal terms
10    if (kf .ne. (ki + 2)) goto 20
      rotham = bmc*sqrt((fjj1 - fk*(fk + 1.d0))
     :  *(fjj1 - (fk + 1.d0)*(fk + 2.d0)))
      goto 1000
20    if (kf .ne. (ki - 2)) goto 900
      rotham = bmc*sqrt((fjj1 - fk*(fk - 1.d0))
     :  *(fjj1 - (fk - 1.d0)*(fk - 2.d0)))
      goto 1000
900   rotham = 0.d0
1000  continue
      return
      end
* ----------------------------------------------------------------------
