* ------------------------------------------------------------------
      subroutine trnprt(filnam,a)
*
* subroutine to calculate effective cross sections for transport 
* from s-matrix elements
*
* see G. C. Maitland, M. Mustafa, W. A. Wakeham, and F. R. McCourt, 
* Mol. Phys. 61, 359 (1987); L. Monchick and S. Green, J. Chem. Phys.
* 63, 2000 (1975); G. A. Parker and R. T Pack, J. Chem. Phys. 68,
* 1585 (1978)
*
* this subroutine returns the effective cross sections for diffusion and
* viscosity, Q(n)(j1->j2)(E), where n=1 and 2.
*
* this subroutine requires CC s-matrix for both parities
*
* author: p.j. dagdigian
* modified from hitensor.f
*
* current revision date:  2-aug-2011 by pjd
* ------------------------------------------------------------------
      implicit double precision (a-h,o-z)
      character*(*) filnam
      character*40  trnfil, smtfil
      character*20  cdate
      character*13  elaps, cpu
      logical csflag, flaghf, flagsu, twomol, exstfl, lpar,
     :        batch, nucros,lpar2
*
      include "common/partens"
      include "common/parpot"
      common /colpar/ lpar(3), batch, lpar2(23)
      common /cospbf/ lnbufs, lnbufl, nbuf, maxlsp, maxllb, ihibuf,
     :                igjtp
      common /comom/  spin, xj1, xj2, j1, in1, j2, in2, maxjt, maxjot,
     :     nwaves, jfsts, jlparf, jlpars, njmax, j1min, j2max, jpmax
      common /cosout/ nnout, jout(25)
      common /coisc2/ inlev(1)
      common /coisc3/ jlev(1)
      common /coisc4/ jpack(1)
      common /coisc5/ lpack(1)
      common /coisc6/ ipack(1)
      common /coisc8/ jlist(1)
      common /coisc9/ jslist(1)
      common /coisc10/ inlist(1)
      common /cojq/ jq(1)
      common /colq/ lq(1)
      common /coinq/ inq(1)
      common /cosc1/  elev(1)
      common /cosc2/  prefac(1)
      common /cosc3/  etrans(1)
      common /cozmat/ jtotpa(1)
      common /coamat/ labadr(1)
      common /colnlb/ lenlab(1000)
      common /coz/    sreal(1)
      common /cow/    simag(1)
      common /cobmat/ sigma(kkmx*jmx*jmx)
      common /cotble/ npnt, jttble(1)
      common /coconv/ econv, xmconv, ang2c
      common /codim/  nairy, mmax
      save nout
      dimension a(6)
      data  tol,   zero,   nstep
     :    /1.d-7,  0.d0,     2/
*
* initialize timer and arays
      call mtime(cpu0,ela0)
      srealp(lbufs)=zero
      simagp(lbufs)=zero
      ipackp(lbuflb)=0
      jpackp(lbuflb)=0
      lpackp(lbuflb)=0
      lnbufs = lbufs
      lnbufl = lbuflb
* input
      iener = a(1)
      in1 = a(2)
      in2 = a(3)
      maxjot = a(4)
      j1min = a(5)
      j2max = a(6)
      if (iener.le. 0) iener = 1
*
* generate filename and check if it is present
*
      call gennam(smtfil,filnam,iener,'smt',lenfs)
      inquire(file = smtfil, exist = exstfl)
      if (.not. exstfl) then
          write(6,10) smtfil(1:lenfs)
10        format(' ** FILE ',(a),' NOT FOUND **')
          return
      end if
*
* open smatrix-file
*
      call openf(1,smtfil,'du',0)
*
        call gennam(trnfil,filnam,iener,'trn',lenft)
        call openf(2,trnfil,'sf',0)
*
* read header of smatrix-file
*
      call rdhead(1,cdate,ered,rmu,csflag,flaghf,flagsu,twomol,
     :   nucros,jfirst,jfinal,jtotd,numin,numax,nud,nlevel,nlevop,nnout,
     :   jlev,inlev,elev,jout)
*
* we need the s-matrices as lower triangles, so nnout  m u s t  be > 0
*
      if (nnout.lt.0) then
         write(2,11)
         if(.not.batch) write(6,11)
11       format(' ** NNOUT < 0, ABORT **')
         return
      end if
      nout = nnout
*
*  molecule-molecule cross sections not yet implemented
*
      if (twomol) then
         write(2,12)
         if (.not. batch) write(6,12)
12       format(' *** TRANSPORT CROSS SECTIONS FOR MOLECULE -',
     :          ' MOLECULE COLLISIONS NOT YET IMPLEMENTED ***')
         goto 300
      end if
      if (flagsu) then
         write(2,14)
         if(.not. batch) write(6,14)
14       format(' *** TRANSPORT CROSS SECTIONS FOR SURFACE -',
     :          ' COLLISIONS NOT YET IMPLEMENTED ***')
         goto 300
      end if
      if (csflag) then
         write(2,16)
         if(.not. batch) write(6,16)
16       format(' *** CS TRANSPORT CROSS SECTIONS',
     :          ' NOT IMPLEMENTED ***')
         goto 300
      end if
*
      spin = 0.d0
      if(flaghf) then
         spin = 0.5d0
      end if
*
      write (2, 20) smtfil, cdate, label, potnam
      if(.not. batch) write (6, 20) smtfil, cdate, label,potnam
20    format(/' CLOSE COUPLED TRANSPORT CROSS SECTIONS',/,
     :        ' S-MATRICES READ FROM FILE ',(a),/,
     : '      WRITTEN:   ',(a),/,
     : '      LABEL:     ',(a)/,
     : '      POT NAME:  ',(a))
*
* obtain new date
*
      call dater(cdate)
      write(2, 22) cdate
      if(.not. batch) write(6, 22) cdate
22    format(' DATE:    ',(a))
* reset maxjt to jfinal if necessary
      if (maxjot.eq.0) maxjot = jfinal
      maxjt = min0(jfinal,maxjot)
      if (maxjt .lt. matjot) then
        write (2, 23) maxjot, jfinal
        if (.not. batch) write (6, 23) maxjot, jfinal
23      format (' MAX(JTOT) RESET TO JFINAL = ',i4, ' IN TRNPRT')
      endif
      maxjot = maxjt
* nwaves is the number of partial waves
      nwaves = jfinal - jfirst + 1
* calculate prefactors and check if j' s are in jout list
* save pointer in array jlist
* also save in values in array inlist (pjd)
      nj = 0
      jpmax = -1
      if (j1min.lt.0) j1min = jout(1)
      if (j2max.lt.0) j2max = jout(iabs(nnout))
      do 40 i=1, iabs(nout)
         jo = jout(i)
         if (jo .gt. j2max) goto 45
         if (jo .lt. j1min) goto 40
         do 30 j=1, nlevel
            j1 = jlev(j)
            in = inlev(j)
            if (j1.ne.jo) goto 30
            if (in.ne.in1 .and. in.ne.in2) goto 30
* test that j1 lies between j1min and j2max
             if (j1.lt.j1min .or. j1.gt.j2max) goto 30
             jpmax = max(jpmax, j1)
* include only open channels
            if (ered .gt. elev(j)) then
              nj = nj + 1
              jlist(nj) = j
              jslist(nj) = j1
              inlist(nj) = in
              prefac(nj) = ang2c * 3.1415926535897932d0 /
     :                  (2.d0* rmu * (ered - elev(j)))
              etrans(nj) = ered -elev(j)
            endif
30      continue
40    continue
* check if there had been any match
45    if(nj.eq.0) then
         write(2,50)
         if(.not. batch) write(6,50)
50       format(' *** NO TRANSITIONS FOUND, ABORT ***')
         goto 300
      end if
      njmax = nj
      if(nj.gt.jmx) then
        write(6,51) nj,jmx
51      format(/' TRNPRT: NJ =',i4, ' .GT. JMX = ',i4)
        return
      end if
* build up pointer table for direct access i/o
      call saddr(1,jfirst,jfinal,numin,numax,csflag,jttble,npnt,
     :           jfsts,jlparf,jlpars,ierr)
      if (ierr .ne. 0) goto 300
* read s-matrix for jfinal to find out the maximum buffer length
      jlp = 1
      if (jlparf .eq. 1) jlp = 0
      jj = jlp * nwaves + jfinal + 1
      iaddr = jttble(jj)
      nopen = -1
      call sread ( iaddr, sreal, simag, jtot, jlpar, nu,
     :            jq, lq, inq, ipack, jpack, lpack,
     :             1, mmax, nopen, length, ierr)
* write header
      write(2,60) ered*econv,rmu*xmconv,jfirst,maxjt
      if(.not.batch) write(6,60)
     :  ered*econv,rmu*xmconv,jfirst,maxjt
60    format(/,' ENERGY: ',f11.3,' cm(-1)    MASS: ',f11.3,/,
     :     ' SUMMING PARTIAL WAVES FROM JTOT=',i3,' TO JTOT=',i3)
*
* write level list
      write(2,64)
      if(.not. batch) write(6,64)
64    format(/,' COLUMNS ARE INITIAL STATES; ROWS ARE FINAL STATES')
      write(2,65)
      if(.not. batch) write(6,65)
65    format (/,' LEVEL LIST FOR TENSOR OPACITIES (OPEN CHANNELS)',
     :        /,'   N     J   INDEX  EINT(cm-1)')
      do 68 i = 1, nj
         ii=jlist(i)
         if (.not. flaghf) then
           write(2,66) i,jlev(ii),inlev(ii),elev(ii)*econv
           if(.not.batch) write(6,66) i,jlev(ii),inlev(ii),
     :                                elev(ii)*econv
66         format (i4, 1x, i5, i6, f11.3)
         else
           write(2,67) i,jlev(ii)+spin,inlev(ii),elev(ii)*econv
           if(.not.batch) write(6,67) i,jlev(ii)+spin,inlev(ii),
     :                                elev(ii)*econv
67         format (i4, 1x, f5.1, i6, f11.3)
         endif

68    continue
*
* now compute transport cross sections
      call sigkap(nnout,jfirst,jfinal,jtotd,nj,mmax,jpack,
     :   lpack,ipack,jttble,prefac,sigma,red,
     :   sreal,simag,etrans,lenlab,labadr,
     :   jtotpa,ierr)
      goto 300
300   call closf(1)
      close (2)
      close (3)
      close (4)
      return
999   write(2,1000)
      if(.not.batch) write(6,1000)
1000  format(' *** I/O ERROR IN TRNPRT.  ABORT')
      call closf(1)
      close (2)
      close (3)
      rewind (4)
      close (4)
      return
      end
* ------------------------------------------------------------------
      subroutine sigkap(nnout,jfirst,jfinal,jtotd,nj,mmax,jpack,
     :                lpack,ipack,jttble,prefac,sigma,ered,
     :                sreal,simag,etrans,lenlab,labadr,
     :                jtotpa,ierr)
*
* subroutine to calculate Q(n) effective cross sections
*
* see G. C. Maitland, M. Mustafa, W. A. Wakeham, and F. R. McCourt, 
* Mol. Phys. 61, 359 (1987); L. Monchick and S. Green, J. Chem. Phys.
* 63, 2000 (1975); G. A. Parker and R. T Pack, J. Chem. Phys. 68,
* 1585 (1978)
*
* sub first computes integral of product of differential cross section
* P_k(cos_theta).  the Q(n) cross sections are weighted sums of these
* integrals
*
* author: p. dagdigian
* current revision date: 2-aug-2011 by pj dagdigian
*
*------------------------------------------------------------------------
      implicit double precision (a-h,o-z)
      complex*8 t, tp
      logical diag, diagj, diagin, lpar1, lpar2, batch, ipos
      character*13 elaps, cpu
      common /colpar/ lpar1(3), batch, lpar2(5), ipos, slpar3(17)
      common /cospbf/ lnbufs, lnbufl, nbuf, maxlsp, maxllb, ihibuf,
     :                igjtp
      common /comom/  spin, xj1, xj2, j1, in1, j2, in2, maxjt, maxjot,
     :     nwaves, jfsts, jlparf, jlpars, njmax, j1min, j2max, jpmax
      common /coipar/ ipar(9),iprnt
      include "common/partens"
* common blocks for levels for which xs's to be computed
      common /coisc9/ jslist(1)
      common /coisc10/ inlist(1)
      common /cojq/ jq(1)
      common /colq/ lq(1)
      common /coinq/ inq(1)
*
      dimension sreal(1), simag(1), etrans(1)
      dimension jpack(1),ipack(1),lpack(1)
      dimension prefac(1), labadr(1), jtotpa(1)
      dimension lenlab (1), jttble(1)
      dimension sigma(nj,nj,2), f36j(0:2)
* set array sizes for jtot_max = 300, channel basis length = 300
* note:  mmax2 = lenmx*(lenmx + 1)/2
      parameter (jtotmx = 300, lenmx = 300, mmax2 = 9870)
* storage for s-matrix elements:
*   second letter is real (r), imaginary (i)
*   subscripts:  jtot, jlp (=1/2 for jlpar = +1/-1), size of channel basis array
      dimension sr(0:jtotmx,2,mmax2),si(0:jtotmx,2,mmax2)
* arrays with values of j ,in, and l:
*   subscripts:  jtot, jlp (=1/2 for jlpar = +1/-1), length of channel basis
      dimension j(0:jtotmx,2,lenmx),in(0:jtotmx,2,lenmx),
     :  l(0:jtotmx,2,lenmx)
* length of arrays
*   subscripts:  jtot, jlp (=1/2 for jlpar = +1/-1)
       dimension length(0:jtotmx,2)       
*
* initialize timer
      call mtime(cpu0,ela0)
      ierr = 0
* check that arrays large enough to store s-matrix elements
      if (maxjt .gt. jtotmx) then
        write(6,1093) jtotmx
1093    format(/' ** JFINL.GT.JTOTMAX=',i3',. ABORT **'/)
        return
      end if     
* clear sigma array
      do 6 k = 0,2
      do 5 ij = 1, njmax
      do 4 i = 1, njmax
        sigma(i,ij,k) = 0.d0
4     continue
5     continue
6     continue
      if(j2max.gt.jmx) then
        write(6,7) j2max,jmx
7       format(/' SIGKAP: jmx too small:',2i5)
        ierr=-1
        return
      end if
      diagin = .false.
      if (in1. eq. in2) diagin = .true.
*
* read s-matrix elements
* this assumes that jlpar=1 is stored first
* scattering calculation should be carried out with jlpar = 0
*
* parameter to read lower triangle of open channel(s)
* read s-matrix for jfinal to find out the maximum buffer length
*
* get address of first partial wave
      jj = jfirst + 1
      iaddr = jttble(jj)
20    nopen = -1
      call sread (iaddr, sreal, simag, jtot, jlpar,
     :   nu, jq, lq, inq, ipack, jpack, lpack,
     :   1, mmax, nopen, lngth, ierr)
      if (ierr .lt. -1) then
        write(6,105)
105     format(/' ** READ ERROR IN TRNPRT. ABORT **'/)
        return
      end if
      iaddr = 0
      if (lngth.gt.lenmx) then
         write(6,106) lenmx
106      format(/' ** LNGTH.GT.LENMX=',i3,'. ABORT **'/)
         return
      end if
      jlp = 1 - (jlpar - 1)/2
*  copy s-matrix for this jtot1/jlpar1
      length(jtot,jlp) = lngth
      len2 = lngth*(lngth + 1)/2
      do i = 1, lngth
        j(jtot,jlp,i) = jpack(i)
        in(jtot,jlp,i) = ipack(i)
        l(jtot,jlp,i) = lpack(i)
      end do
      do ii = 1, len2
        sr(jtot,jlp,ii) = sreal(ii)
        si(jtot,jlp,ii) = simag(ii)
      end do
*
* read s-matrix for next jtot/jlpar
      if (jtot.lt.maxjt .or. jlpar.eq.1) goto 20
*
* sum over the jtot/jlpar pairs
      do jtot = jfirst, maxjt
        xjtot = jtot + spin
        facj = 2.d0 * xjtot + 1.d0
          do jlp = 1, 2
            jlpar = 1 - (jlp - 1)*2
*
* boundaries of sum over jtotp
            jtpmin = max((jtot - 2), jfirst)
            jtpmax = min((jtot + 2), maxjt)
            do jtotp = jtpmin, jtpmax
              xjtotp = jtotp + spin
              facjjp = (2.d0 * xjtotp + 1.d0) * facj
              do jlpp = 1, 2
                jlparp = 1 - (jlpp - 1)*2
*
* sum over row index for jtot
                do 400 irow = 1, length(jtot,jlp)
                  j1 = j(jtot,jlp,irow)
                  xj1 = j1 + spin
                  if (j1 .gt. j2max) goto 400
                  if (j1 .gt. jpmax) goto 400
                  if (j1 .lt. j1min) goto 400
                  l1 = l(jtot,jlp,irow)
                  xl1 = l1
                  sl1 = sqrt(2.d0 * xl1 + 1.d0)
                  do 74 ij = 1, njmax
                    if (j1 .ne. jslist(ij)) goto 74
                    if (in(jtot,jlp,irow) .ne. inlist(ij)) goto 74
                    ir = ij
                    denrow = prefac(ij)
                    etrow = etrans(ij)
                    goto 75
74                continue
* level not in list
                  goto 400
75                continue
*
* sum over column index for jtot
                  do 200 icol = 1, length(jtot,jlp)
                    if (in(jtot,jlp,irow) .eq. in1 .and.
     :                in(jtot,jlp,icol) .eq. in2) goto 82
                    if (in(jtot,jlp,irow) .eq. in2 .and.
     :                in(jtot,jlp,icol) .eq. in1) goto 82
                    goto 200
82                  continue
                    j2 = j(jtot,jlp,icol)
                    xj2 = j2 + spin
                    if (j2 .gt. j2max) goto 200
                    if (j2 .gt. jpmax) goto 200
                    if (j2 .lt. j1min) goto 200
                    l2 = l(jtot,jlp,icol)
                    xl2 = l2
                    sl2 = sqrt(2.d0 * xl2 + 1.d0)
                    diagj = j1.eq.j2
                    do 84 ij = 1, njmax
                      if (j2 .ne. jslist(ij)) goto 84
                      if (in(jtot,jlp,icol) .ne. inlist(ij)) goto 84
                      ic = ij
                      etcol = etrans(ij)
                      goto 85
84                    continue
* level not in list
                    goto 200
85                  continue
*
* sum over row index for jtotp
                    do 401 irowp = 1, length(jtotp,jlpp)
                      j1p = j(jtotp,jlpp,irowp)
                      xj1p = j1p + spin
                      if (j1p .ne. j1) goto 401
                      if (in(jtotp,jlpp,irowp) .ne. in(jtot,jlp,irow))
     :                  goto 401
                      l1p = l(jtotp,jlpp,irowp)
                      xl1p = l1p
                      sl1p = sqrt(2.d0 * xl1p + 1.d0)
*
* sum over column index for jtotp
                      do 201 icolp = 1, length(jtotp,jlpp)
                        j2p = j(jtotp,jlpp,icolp)
                        xj2p = j2p + spin
                        if (j2p .ne. j2) goto 201
                        if (in(jtotp,jlpp,icolp) .ne. in(jtot,jlp,icol))
     :                    goto 201
                        l2p = l(jtotp,jlpp,icolp)
                        xl2p = l2p
                        sl2p = sqrt(2.d0 * xl2p + 1.d0)
* get s-matrix elements
                       if (irow .gt. icol) then 
                         ii = (irow*(irow - 1))/2 + icol
                       else
                         ii = (icol*(icol - 1))/2 + irow
                       end if
                       if (irowp .gt. icolp) then
                         iip = (irowp*(irowp - 1))/2 + icolp
                       else
                         iip = (icolp*(icolp - 1))/2 + irowp
                       end if
                       diag = diagj .and. diagin
* phase factor
                       phase = 1.d0
                       ipower = nint(xj1 - xj2 
     :                   - 0.5d0*(xl1 - xl1p + xl2 - xl2p))
                       if ((ipower/2)*2 .ne. ipower) phase = -1.d0
* get T-matrix elements
                       t = - cmplx(sr(jtot,jlp,ii), si(jtot,jlp,ii))
                       if (diag .and. (l1.eq.l2))
     :                   t = (1.d0, 0.d0) + t
                       tp=-cmplx(sr(jtotp,jlpp,iip),si(jtotp,jlpp,iip))
                       if (diag .and. (l1p.eq.l2p))
     :                   tp = (1.d0, 0.d0) + tp
                       factor = phase * facjjp * sl1 * sl2 * sl1p 
     :                   * sl2p * real(t*conjg(tp))/(2.d0*xj1 + 1.d0)
*
* loop over k
                      do 100 k = 0, 2
                        xappa = k
                        f36j(k) = factor
     :                    * xf3j(xl1,xl1p,xappa,0.d0,0.d0,0.d0)
     :                    * xf3j(xl2,xl2p,xappa,0.d0,0.d0,0.d0)
     :                    * xf6j(xl1,xjtot,xj1,xjtotp,xl1p,xappa)
     :                    * xf6j(xl2,xjtot,xj2,xjtotp,xl2p,xappa)
     :                    * (-1.d0)**k
100                   continue
                      epove = etcol/etrow
*
* N = 1
                      fac1 = f36j(0) - sqrt(epove)*f36j(1)
                      sigma(ic,ir,1) = sigma(ic,ir,1) + fac1*denrow
*
* N = 2
                      fac2 = f36j(0) * (1.d0 - (1 - epove))**2
     :                  - epove*f36j(2)
                      sigma(ic,ir,2) = sigma(ic,ir,2) + fac2*denrow
201                 continue
401               continue
200             continue
400           continue
            end do
          end do
        end do
      end do
*
* here when calculation has been done
999   do 1100 k = 1, 2
        write(2,800) k
        if(.not.batch) write(6,800) k
800     format(/' N =',i3)
        call mxoutd (2, sigma(1,1,k), njmax, njmax, 0, ipos)
* use diag as scratch variable (ipos = .false. for screen output)
        diag = .false.
        if(.not. batch)
     :    call mxoutd (6, sigma(1,1,k), njmax, njmax, 0, diag)
1100  continue
*
      call mtime(cpu1,ela1)
      cpu1 = cpu1 - cpu0
      ela1 = ela1 - ela0
      call gettim(ela1,elaps)
      call gettim(cpu1,cpu)
      write(2,1200) elaps, cpu
      if(.not. batch) write(6,1200) elaps, cpu
1200  format(/' ** TIMING ELAPSED: ',a,
     :        ' CPU: ',a,/)
      return
      end
c=====eof=====

