* System:  OH(X 2Pi)+H, triplet potentials from MRCI calculations
* Reference: M. H. Alexander, E. J. Rackham, D. E. Manolopoulos,
*     J. Chem. Phys. to be published.


      subroutine driver
      implicit double precision (a-h,o-z)
      common /cosysr/ xjunk(2),rshift,xfact
      common /covvl/ vvl(15)
      common /coconv/ econv
      include "common/parpot"
      potnam='ALEXANDER OH-H Triplet MRCI'
      econv=219474.6d0
1      print *, ' r (bohr)'
      rshift=0.5
      xfact=0.8
      read (5, *, end=99) r
      call pot(vv0,r)
      write (6, 100) vv0,vvl
100   format(' vsum',/,9(1pe16.8),/,
     :    ' vdif',/,7e16.8)
      goto 1
99    end
      include "common/syusr"
      include "common/bausr"
      include "common/ground"
* --------------------------------------------------------------------------
      subroutine loapot(iunit,filnam)
* --------------------------------------------------------------------------
      character*(*) filnam
      include "common/parbas"
      include "common/parpot"
      potnam='ALEXANDER OH-H Triplet MRCI'
      lammin(1)=1
      lammax(1)=8
      lammin(2)=2
      lammax(2)=8
      mproj(1)=0
      mproj(2)=2
      ntv(1)=1
      ivcol(1,1)=0
      ivrow(1,1)=0
      return
      end
* --------------------------------------------------------------------------
      subroutine pot(vv0,rr)
* subroutine to determine OH-H ab initio interaction potentials (including OH
*    vibrational potential
*    includes points from 3.0 bohr up to 12 bohr
* on entry:
*      rr:   value of R in bohr
*      ifirst:  zero for the first entry into this subroutine, then set to 1

* on return
*  vv0      spherically symmetric term in V0
*  variable in common block /covvl/
*    vvl:     vector of length 15 to store r-dependence of each term
*             in potential expansion
*    vvl(1-8) expansion coefficients in dl0 (l=1:8) of vsum
*    vvl(9-15) expansion coefficients in dl2 (l=2:8) of vdif

* uses linear least squares routines from cmlib
* --------------------------------------------------------------------------

      implicit double precision (a-h,o-z)
      dimension cr7(72,4),cr8(72,4),cr9(72,4),cr1(72,4),cr12(72,4),
     : cr14(72,4),cr(72,4)
      dimension alphlr7(9,4),alphlr8(9,4),alphlr9(9,4),alphlr1(9,4),
     :          alphlr12(9,4),alphlr14(9,4),alphlr(9,4)
      dimension alr7(9,4),alr8(9,4),alr9(9,4),alr1(9,4),
     :          alr12(9,4),alr14(9,4),alr(9,4)
      dimension d0(9,9),d2(7,7),roh(6),vgamma(4),v(6,9,4),
     :   vsum(9,2),vdif(9,2),vvsum(2),vvdif(2)

* arrays needed for linear least squares fit for r dependence
      dimension vander(6,6),ar(6,6),qrauxr(9),work(27),vroh(6),
     :     rsd(9),croh(6,9,4),xroh(6),xxroh(6),kpvtr(6)
* arrays needed for linear least squares fit for gamma dependence
      dimension ag0(9,9),qrauxg0(9),vgam(9),kpvtg0(9),kpvtg2(7),
     :          ag2(7,7),qrauxg2(9),xgam(9),xgam0(9,2),xgam2(7,2),
     :          pl0(9),pl2(9)

      common /covvl/ vvl(15)
* data for initializataion for linear least squares routines
      data ifirst /0/
* conversion factor from cm-1 to hartree
      data tohar / 4.5563359d-6/
* fit to OH-H ab initio avqz points with Rmin=3.5 bohr at 6 values of roh
*  roh=[0.74966 0.84966 0.96966 1.11966 1.24966 1.41966],angstroms

* here are the 6 oh distances in bohr
      data roh /
     : 1.4166522d0, 1.6056249d0, 1.8323920d0, 2.1158510d0,
     : 2.3615154d0, 2.6827689d0/

* and 9 values of gamma [0:22.5:180]

* fit for each angle and each roh is
*   V(R,r,gamma) = [1-S(R)]*sum(n=0:7)*C(r,gamma)*[1-exp(-(R-Ro)/alph]^n
*         +S(R)*Alr*exp(alphlr*R)
*   where Ro=5 and alph=2, and S(R)=0.5*[1+tanh(R-8.5)]
       data rro, alphrr /5d0,2d0/
* the coefficients are stored by column order in two-dimensional arrays
* cr{j}(n,nsurf), where
*   {j} is the index of the value of roh [7,8,9,1,12,14]
*   {nsurf} is the electronic state with
*         nsurf=1 corresponding to 1A',
*         nsurf=2               1A"
*         nsurf=3               3A'
*         nsurf=4               3A"

* for n=1-5 the coefficients correspond to gamma=0
* for n=6-10, to gamma=22.5, etc

* the fit in r is also done as a power series in xr=1-exp(-(r-ro)/alph)
* where the coefficients are
      data ro,alphr /1.8324d0,2d0/
* constants
      data zero, one, two, half /0d0, 1d0, 2d0, 0.5d0/

* dimension cr7(72,4)
      data cr7/
     : 3.1949116d0, 1.1371924d+1, 1.4589337d+1, -9.2633933d+1,
     : -5.4627129d+2, 1.4781165d+3, -1.1238794d+3, 2.5255150d+2,
     : -2.2696947d+2, -4.1441812d+2, 5.7122996d+2, -5.8465806d0,
     : -5.3526661d+1, 3.9342550d+2, -4.1701468d+2, 7.1327466d+1,
     : 1.2349591d+1, 1.4101395d+2, -2.7257736d+1, -5.3270360d+2,
     : 1.1932894d+3, -1.5641211d+3, 1.1713272d+3, -3.7561133d+2,
     : 3.0639112d+1, 1.9759168d+1, -2.7513674d+2, 1.2564413d+2,
     : 1.4942491d+3, -3.2722096d+3, 2.6959861d+3, -8.1754943d+2,
     : -2.7012615d0, -9.4475858d+1, -2.2379435d+2, 5.2101686d+2,
     : 1.2541530d+3, -3.7714853d+3, 3.3334476d+3, -1.0273904d+3,
     : -3.5005385d0, -6.6604879d+1, -1.4498623d+2, 4.0248538d+2,
     : 9.0292596d+2, -2.9925511d+3, 2.7944109d+3, -9.0007115d+2,
     : 6.1112885d+1, 1.2970469d+2, -1.0053626d+2, -1.5521779d+2,
     : 4.1852361d+2, -1.0677524d+3, 1.2084369d+3, -4.6822976d+2,
     : -7.6070905d+1, -1.1016540d+2, 2.0675500d+2, -3.2273082d+1,
     : -5.8635262d+2, 1.2277026d+3, -7.3396229d+2, 7.4726216d+1,
     : 1.5823528d0, 3.5005447d+1, 1.9711980d+1, -4.5283613d+1,
     : -1.1522418d+3, 2.4883091d+3, -1.6890845d+3, 3.3708164d+2,
     : 3.2357333d0, 1.1478361d+1, 1.4579952d+1, -9.2810592d+1,
     : -5.4632254d+2, 1.4782503d+3, -1.1239274d+3, 2.5255943d+2,
     : 1.2225212d+1, 4.6484694d+1, 4.6034632d+1, -1.0656638d+2,
     : -5.2389404d+2, 1.4793155d+3, -1.1598145d+3, 2.3649682d+2,
     : 1.7658471d+1, 5.6331856d+1, 3.1136002d+1, -1.3844824d+2,
     : -4.4961653d+2, 1.4478771d+3, -1.2158622d+3, 2.6847707d+2,
     : 1.2808851d+1, 3.9449350d+1, 1.4854324d+1, -1.3107393d+2,
     : -3.6171214d+2, 1.3714939d+3, -1.2356462d+3, 2.9277451d+2,
     : 9.5473857d0, 3.0379091d+1, 8.8133086d0, -1.1434504d+2,
     : -3.2046007d+2, 1.2920039d+3, -1.2009553d+3, 2.9233031d+2,
     : 9.6797188d0, 3.1788403d+1, 1.1612989d+1, -9.8507539d+1,
     : -3.7556472d+2, 1.3195341d+3, -1.1769846d+3, 2.7585601d+2,
     : 6.2968477d+1, 1.4204618d+2, -3.1120586d+1, -2.2100804d+2,
     : -5.5568458d+2, 1.6465947d+3, -1.2847075d+3, 2.6816312d+2,
     : -1.7123682d-2, 4.7394944d+1, 7.8831073d+1, -6.1527732d+1,
     : -9.5660735d+2, 2.1572076d+3, -1.5348604d+3, 2.8911304d+2,
     : 1.6772449d0, 3.5268525d+1, 1.9725980d+1, -4.5667017d+1,
     : -1.1523757d+3, 2.4884734d+3, -1.6890269d+3, 3.3704317d+2,
     : 3.2978572d0, 1.3602039d+1, 1.5302017d+1, -5.4231791d+1,
     : -4.4621540d+2, 1.0242303d+3, -6.6351541d+2, 1.0632000d+2,
     : 4.3788224d0, 1.7781100d+1, 1.8194544d+1, -6.1475645d+1,
     : -4.8514925d+2, 1.1270244d+3, -7.5573792d+2, 1.3514210d+2,
     : 5.4417687d0, 1.6467456d+1, 2.2487460d+1, -6.1238091d+1,
     : -5.7430093d+2, 1.3565380d+3, -9.6710175d+2, 2.0225011d+2,
     : 4.6270327d0, 1.3937248d+1, 2.4752065d+1, -5.3288885d+1,
     : -6.5686224d+2, 1.5569924d+3, -1.1518603d+3, 2.6166604d+2,
     : 3.5095348d0, 1.2306658d+1, 2.1576027d+1, -3.8698369d+1,
     : -6.9997144d+2, 1.6291092d+3, -1.2066324d+3, 2.7751313d+2,
     : 3.3318376d0, 1.2838660d+1, 2.1707081d+1, -3.1445303d+1,
     : -7.2487889d+2, 1.6211808d+3, -1.1557348d+3, 2.5077290d+2,
     : 4.8623537d+1, 1.0434512d+2, -2.1850546d+1, -1.5023450d+2,
     : -7.6264478d+2, 1.7093393d+3, -1.1196378d+3, 2.1115599d+2,
     : -1.4509125d+1, 1.1879695d0, 5.5391226d+1, -4.8150833d0,
     : -9.3130206d+2, 1.8519242d+3, -1.1574475d+3, 1.9071151d+2,
     : 9.7450611d-1, 3.7861530d+1, 2.1863381d+1, -1.9116465d+1,
     : -1.0156638d+3, 1.9910195d+3, -1.2059637d+3, 1.8620179d+2,
     : 3.3007723d0, 1.3615078d+1, 1.5317660d+1, -5.4235195d+1,
     : -4.4622450d+2, 1.0242463d+3, -6.6355045d+2, 1.0633369d+2,
     : 1.0557829d+1, 3.9470337d+1, 3.1240008d+1, -7.1279820d+1,
     : -4.2041983d+2, 1.0100088d+3, -6.7722167d+2, 9.5630285d+1,
     : 1.1710103d+1, 3.6178075d+1, 1.1200417d+1, -7.7630031d+1,
     : -3.4178538d+2, 9.3778209d+2, -6.7688599d+2, 1.0592861d+2,
     : 8.5120623d0, 2.4607838d+1, -1.8151541d-1, -6.4231758d+1,
     : -2.6994822d+2, 8.3695650d+2, -6.4652394d+2, 1.0955587d+2,
     : 7.0135758d0, 2.0712445d+1, -3.0905881d0, -5.1359345d+1,
     : -2.4232513d+2, 7.6810116d+2, -6.0733039d+2, 1.0474954d+2,
     : 6.8786784d0, 2.1595053d+1, 1.6550361d-1, -4.1688074d+1,
     : -2.9735393d+2, 8.2977552d+2, -6.2601435d+2, 1.0298325d+2,
     : 5.4039009d+1, 1.1900462d+2, -4.0990815d+1, -1.6133180d+2,
     : -4.5673243d+2, 1.1754894d+3, -7.8688270d+2, 1.1765860d+2,
     : -5.7529941d0, 3.0335359d+1, 5.9391887d+1, -2.6416784d+1,
     : -8.2053588d+2, 1.6774268d+3, -1.0599574d+3, 1.5148158d+2,
     : 9.9815170d-1, 3.7932934d+1, 2.1881223d+1, -1.9204341d+1,
     : -1.0157180d+3, 1.9910566d+3, -1.2059428d+3, 1.8619445d+2/
      data cr8/
     : 4.4699725d0, 1.5939517d+1, 1.9111365d+1, -9.9211537d+1,
     : -5.4173927d+2, 1.4522445d+3, -1.0961644d+3, 2.4393595d+2,
     : -1.5349820d+2, -2.8308441d+2, 4.3168812d+2, -1.2530317d+2,
     : -1.0135016d+1, 3.9985616d+2, -3.7124760d+2, 5.4519792d+1,
     : 1.3385292d+1, 1.2343958d+2, -4.5486391d+1, -4.8082458d+2,
     : 1.1512155d+3, -1.5874615d+3, 1.2407268d+3, -4.0129970d+2,
     : 2.6413465d+1, 6.8951745d0, -2.6776687d+2, 1.4995167d+2,
     : 1.4407797d+3, -3.2694036d+3, 2.7557640d+3, -8.4297021d+2,
     : -3.6990387d0, -9.5407599d+1, -2.1644787d+2, 5.1721618d+2,
     : 1.2128643d+3, -3.7468558d+3, 3.3659797d+3, -1.0432688d+3,
     : -1.1180481d0, -5.7369829d+1, -1.4450373d+2, 3.7149241d+2,
     : 8.9326575d+2, -2.9537305d+3, 2.7884142d+3, -9.0059269d+2,
     : 7.7655277d0, 3.7227329d+1, -4.1972364d+1, -9.5932070d+1,
     : 4.4414812d+2, -1.0282635d+3, 1.1157507d+3, -4.3522152d+2,
     : -3.7852848d+1, -4.9790824d+1, 1.5819830d+2, -2.2933396d+2,
     : -4.9884812d+2, 1.5112170d+3, -1.0360755d+3, 1.6458494d+2,
     : -3.0782433d0, 5.3518452d+1, -8.7604748d0, -1.0775367d+2,
     : -1.1901908d+3, 2.9135310d+3, -2.1214409d+3, 4.5859732d+2,
     : 4.4620152d0, 1.5910004d+1, 1.9087968d+1, -9.9199957d+1,
     : -5.4171022d+2, 1.4522938d+3, -1.0962472d+3, 2.4395171d+2,
     : 4.6488540d0, 1.5253930d+1, 1.3947637d+1, -1.0712047d+2,
     : -5.1040761d+2, 1.4519367d+3, -1.1294302d+3, 2.5978020d+2,
     : 4.1256516d0, 1.1493403d+1, 1.4820794d0, -1.1971552d+2,
     : -4.2889373d+2, 1.4270725d+3, -1.1909208d+3, 2.9366782d+2,
     : 3.5400749d0, 7.0781079d0, -1.1911557d+1, -1.2226657d+2,
     : -3.4091496d+2, 1.3586627d+3, -1.2135545d+3, 3.1757224d+2,
     : 2.0407643d0, 2.4827273d0, -1.8063413d+1, -1.0818874d+2,
     : -2.9724162d+2, 1.2842473d+3, -1.1860205d+3, 3.1888236d+2,
     : 1.8147665d0, 3.0565627d0, -1.6664357d+1, -9.8043006d+1,
     : -3.4752928d+2, 1.3405505d+3, -1.1994796d+3, 3.1419006d+2,
     : 3.2221709d0, 1.0910959d+1, -9.0069523d0, -1.1757345d+2,
     : -5.3856391d+2, 1.7171974d+3, -1.4106106d+3, 3.4092354d+2,
     : 8.9865634d0, 4.1631589d+1, -1.4026949d+1, -1.5090451d+2,
     : -9.0110740d+2, 2.4519172d+3, -1.8528534d+3, 4.1280743d+2,
     : -3.3368861d0, 5.3024651d+1, -8.3133578d0, -1.0695321d+2,
     : -1.1906446d+3, 2.9132822d+3, -2.1213002d+3, 4.5856339d+2,
     : 3.7802748d0, 1.5168634d+1, 1.7109281d+1, -5.8371290d+1,
     : -4.3777338d+2, 9.9587372d+2, -6.3093988d+2, 9.4242460d+1,
     : 4.4421412d0, 1.5418382d+1, 1.9761236d+1, -5.8982092d+1,
     : -4.8102406d+2, 1.1062533d+3, -7.3078377d+2, 1.2492815d+2,
     : 3.7850663d0, 1.2054531d+1, 2.4810960d+1, -5.7330131d+1,
     : -5.7629243d+2, 1.3509284d+3, -9.5525524d+2, 1.9614988d+2,
     : 3.9603451d0, 1.1891701d+1, 2.4269136d+1, -5.1476548d+1,
     : -6.5910589d+2, 1.5576020d+3, -1.1464663d+3, 2.5794290d+2,
     : 4.2632210d0, 1.4251952d+1, 2.1149290d+1, -4.2542385d+1,
     : -7.0022186d+2, 1.6306189d+3, -1.2045529d+3, 2.7573760d+2,
     : 4.4328751d0, 1.6475349d+1, 2.2834121d+1, -4.4546367d+1,
     : -7.1959859d+2, 1.6409207d+3, -1.1760225d+3, 2.5433342d+2,
     : 5.1195148d0, 2.0867628d+1, 2.6290423d+1, -7.5545498d+1,
     : -7.6286654d+2, 1.7449802d+3, -1.1902881d+3, 2.2866487d+2,
     : 7.7177698d0, 4.7542820d+1, 9.7420625d0, -1.0771460d+2,
     : -8.7351065d+2, 1.9921089d+3, -1.2943837d+3, 2.1794962d+2,
     : 2.9107776d0, 7.3299528d+1, -2.5027041d+1, -8.9458734d+1,
     : -9.6834273d+2, 2.1554929d+3, -1.3679834d+3, 2.1758572d+2,
     : 3.7755365d0, 1.5172369d+1, 1.7151665d+1, -5.8338428d+1,
     : -4.3778293d+2, 9.9576110d+2, -6.3084516d+2, 9.4212126d+1,
     : 4.6421138d0, 1.6383027d+1, 1.0793239d+1, -6.4760222d+1,
     : -4.0878656d+2, 9.7972771d+2, -6.3816187d+2, 9.9590659d+1,
     : 4.6983683d0, 1.2341489d+1, -4.5925695d0, -6.7570676d+1,
     : -3.3116538d+2, 9.1470169d+2, -6.3888594d+2, 1.0922785d+2,
     : 3.3596992d0, 5.9924027d0, -1.6189261d+1, -5.7962982d+1,
     : -2.5548568d+2, 8.1610731d+2, -6.0908720d+2, 1.1165583d+2,
     : 2.4666339d0, 3.2934309d0, -2.0251213d+1, -4.4734297d+1,
     : -2.2353996d+2, 7.4722687d+2, -5.7320057d+2, 1.0763862d+2,
     : 2.3639860d0, 4.7643980d0, -1.7982033d+1, -4.0938508d+1,
     : -2.7120549d+2, 8.2085535d+2, -6.1085983d+2, 1.1196797d+2,
     : 3.3884672d0, 1.2586549d+1, -1.3222750d+1, -6.6805189d+1,
     : -4.2703297d+2, 1.1619612d+3, -8.1509493d+2, 1.4169053d+2,
     : 7.1406415d0, 3.9713919d+1, -2.4329750d+1, -9.9618037d+1,
     : -7.2026053d+2, 1.7716685d+3, -1.1708796d+3, 1.9226641d+2,
     : 3.3653430d0, 7.4340840d+1, -2.5361320d+1, -9.0920443d+1,
     : -9.6825801d+2, 2.1559988d+3, -1.3679790d+3, 2.1753897d+2/
      data cr9/
     : 4.2890033d0, 1.4785269d+1, 2.0803281d+1, -1.0287347d+2,
     : -5.1875793d+2, 1.4006587d+3, -1.0467111d+3, 2.2628557d+2,
     : -1.3980048d+2, -2.4543553d+2, 4.0101879d+2, -1.6164482d+2,
     : 3.0099671d+1, 3.4132265d+2, -3.0751905d+2, 3.1642619d+1,
     : 1.7737980d+1, 1.1959015d+2, -6.8549846d+1, -4.3776572d+2,
     : 1.1548933d+3, -1.6683743d+3, 1.3264380d+3, -4.3054146d+2,
     : 2.1799104d+1, -8.3192451d0, -2.5939695d+2, 1.9982166d+2,
     : 1.4013277d+3, -3.3133457d+3, 2.8252572d+3, -8.6895807d+2,
     : -5.9418637d0, -9.9290084d+1, -2.0500987d+2, 5.3011113d+2,
     : 1.1786420d+3, -3.7415530d+3, 3.3900354d+3, -1.0565307d+3,
     : 1.7812115d0, -4.8949544d+1, -1.5091775d+2, 3.4091213d+2,
     : 9.1633119d+2, -2.9240526d+3, 2.7570066d+3, -8.9541551d+2,
     : 1.8848428d+1, 7.5456748d+1, -7.8775844d+1, -2.3255406d+2,
     : 6.1465979d+2, -9.7547342d+2, 9.7670295d+2, -3.9140020d+2,
     : -1.4111940d+2, -1.5211354d+2, 3.1378118d+2, -3.3198665d+2,
     : -2.9068767d+2, 1.6647570d+3, -1.3977313d+3, 2.8675802d+2,
     : 2.7926011d0, 1.3658357d+2, -1.4348725d+2, -2.5547021d+2,
     : -1.0029742d+3, 3.2998049d+3, -2.6694647d+3, 6.3144444d+2,
     : 4.2883886d0, 1.4771201d+1, 2.0776938d+1, -1.0287724d+2,
     : -5.1871006d+2, 1.4007401d+3, -1.0468388d+3, 2.2630189d+2,
     : 4.0348260d0, 1.2877530d+1, 1.5147698d+1, -1.0878933d+2,
     : -4.8851254d+2, 1.4068352d+3, -1.0886975d+3, 2.4530017d+2,
     : 4.2744520d0, 1.0902234d+1, 1.0844512d0, -1.2223630d+2,
     : -4.1063206d+2, 1.3964332d+3, -1.1667874d+3, 2.8535731d+2,
     : 3.2941612d0, 5.2083884d0, -1.3308317d+1, -1.1960320d+2,
     : -3.2615654d+2, 1.3345601d+3, -1.1992748d+3, 3.1345238d+2,
     : 1.7676917d0, 3.3672359d-1, -2.0246877d+1, -1.0433118d+2,
     : -2.8214352d+2, 1.2639939d+3, -1.1790200d+3, 3.1777889d+2,
     : 1.4246639d0, 2.6158726d-1, -2.1750576d+1, -1.0372811d+2,
     : -3.1677289d+2, 1.3452058d+3, -1.2344281d+3, 3.2748603d+2,
     : 2.8315693d0, 7.8402069d0, -2.7504005d+1, -1.6542021d+2,
     : -4.4081140d+2, 1.7986191d+3, -1.5791839d+3, 3.9863757d+2,
     : 7.6447419d0, 4.2769531d+1, -8.4262065d+1, -2.4344948d+2,
     : -7.0012862d+2, 2.6762312d+3, -2.2523214d+3, 5.4404300d+2,
     : 2.8475421d0, 1.3678590d+2, -1.4340327d+2, -2.5583868d+2,
     : -1.0031282d+3, 3.3001008d+3, -2.6695208d+3, 6.3140518d+2,
     : 3.5144035d0, 1.3747819d+1, 1.9543835d+1, -6.3521371d+1,
     : -4.2087693d+2, 9.6375634d+2, -5.9894256d+2, 8.1679003d+1,
     : 4.1676072d0, 1.3577976d+1, 2.1369448d+1, -6.3036453d+1,
     : -4.6897102d+2, 1.0837902d+3, -7.0619991d+2, 1.1458714d+2,
     : 4.2459866d0, 1.1996400d+1, 2.5074418d+1, -6.0261773d+1,
     : -5.7380754d+2, 1.3452246d+3, -9.4352082d+2, 1.8975386d+2,
     : 4.6517421d0, 1.2656004d+1, 2.3399190d+1, -5.2476898d+1,
     : -6.6087510d+2, 1.5562402d+3, -1.1379447d+3, 2.5288450d+2,
     : 3.6079984d0, 1.2138354d+1, 2.0301465d+1, -4.0909711d+1,
     : -6.9589711d+2, 1.6226678d+3, -1.1933458d+3, 2.6949039d+2,
     : 4.4626609d0, 1.6274413d+1, 2.1180457d+1, -5.5523923d+1,
     : -6.9751087d+2, 1.6370984d+3, -1.1793307d+3, 2.5238527d+2,
     : 5.6612213d0, 2.2343552d+1, 1.5577271d+1, -1.2301022d+2,
     : -6.7199651d+2, 1.7379437d+3, -1.2241482d+3, 2.3415448d+2,
     : 1.8491074d+1, 8.2836447d+1, -7.4870217d+1, -2.1503304d+2,
     : -6.0165508d+2, 1.8742033d+3, -1.2963211d+3, 2.1183711d+2,
     : 3.2550204d+1, 1.8782032d+2, -2.5237108d+2, -1.9683246d+2,
     : -5.7972966d+2, 1.9368979d+3, -1.3158534d+3, 1.9379890d+2,
     : 3.5178901d0, 1.3759974d+1, 1.9545675d+1, -6.3544534d+1,
     : -4.2085024d+2, 9.6366571d+2, -5.9884500d+2, 8.1640375d+1,
     : 4.5492262d0, 1.5081733d+1, 1.1997319d+1, -6.9399842d+1,
     : -3.9105337d+2, 9.4845757d+2, -6.0831172d+2, 8.7901891d+1,
     : 4.2700704d0, 1.0068452d+1, -5.0063150d0, -6.7173519d+1,
     : -3.1347298d+2, 8.8106872d+2, -6.0998546d+2, 9.8658198d+1,
     : 2.9714357d0, 3.6389367d0, -1.7443278d+1, -5.2024807d+1,
     : -2.4067345d+2, 7.7753010d+2, -5.7630850d+2, 1.0065811d+2,
     : 2.0188178d0, 8.5235986d-1, -2.1329356d+1, -3.6413222d+1,
     : -2.0922376d+2, 7.0455636d+2, -5.3755958d+2, 9.6171929d+1,
     : 2.3164018d0, 2.9627542d0, -2.2328730d+1, -4.1037949d+1,
     : -2.3718649d+2, 7.7626789d+2, -5.8580610d+2, 1.0405371d+2,
     : 5.2652103d0, 1.5281638d+1, -3.6303973d+1, -1.0284176d+2,
     : -3.0021538d+2, 1.0826656d+3, -8.0514560d+2, 1.3878898d+2,
     : 1.8208324d+1, 6.8761919d+1, -1.2684241d+2, -1.7705871d+2,
     : -4.1391813d+2, 1.5848918d+3, -1.1388579d+3, 1.8086386d+2,
     : 3.2312680d+1, 1.8735839d+2, -2.5198321d+2, -1.9606060d+2,
     : -5.8001081d+2, 1.9365124d+3, -1.3156481d+3, 1.9375115d+2/
      data cr1/
     : 3.8860482d0, 1.1611459d+1, 2.6364840d+1, -1.1329029d+2,
     : -4.6705460d+2, 1.2940756d+3, -9.5292064d+2, 1.9530503d+2,
     : -1.2013405d+2, -1.8800254d+2, 3.5849050d+2, -2.1984426d+2,
     : 9.9027996d+1, 2.3662321d+2, -2.0106006d+2, -4.6885024d0,
     : 2.2814960d+1, 1.1420747d+2, -9.8181090d+1, -3.8159557d+2,
     : 1.1659674d+3, -1.7845605d+3, 1.4446475d+3, -4.7028350d+2,
     : 1.6792783d+1, -2.4507026d+1, -2.4963057d+2, 2.5466303d+2,
     : 1.3575540d+3, -3.3629359d+3, 2.9037765d+3, -8.9881634d+2,
     : -7.7268879d0, -1.0182675d+2, -1.9553990d+2, 5.3655098d+2,
     : 1.1507999d+3, -3.7249181d+3, 3.3982560d+3, -1.0652102d+3,
     : 7.0573773d0, -3.7389303d+1, -1.7284815d+2, 2.9574928d+2,
     : 9.8440560d+2, -2.8944696d+3, 2.6908551d+3, -8.7618963d+2,
     : 5.0873864d+1, 1.5407767d+2, -1.9801260d+2, -4.4993625d+2,
     : 1.0074615d+3, -1.0222580d+3, 7.8910934d+2, -3.1478886d+2,
     : -7.7860248d+1, 2.6390069d+2, 1.6526418d+2, -1.2398700d+3,
     : 6.8796165d+2, 1.5458894d+3, -1.7860993d+3, 4.6260720d+2,
     : 2.4403891d+3, 3.7058755d+3, -4.0347689d+3, -4.4058426d+3,
     : 1.4999204d+3, 4.1936478d+3, -3.3857853d+3, 8.3502912d+2,
     : 3.8899170d0, 1.1614658d+1, 2.6343995d+1, -1.1333532d+2,
     : -4.6701107d+2, 1.2941958d+3, -9.5309384d+2, 1.9535257d+2,
     : 4.7289514d0, 1.2781172d+1, 2.0454571d+1, -1.2213485d+2,
     : -4.4377359d+2, 1.3194550d+3, -1.0123245d+3, 2.1997631d+2,
     : 4.5660926d0, 8.7799676d0, 1.9225589d0, -1.2862856d+2,
     : -3.7812237d+2, 1.3435497d+3, -1.1260190d+3, 2.7216024d+2,
     : 2.8591586d0, 1.8691787d0, -1.4156298d+1, -1.1743756d+2,
     : -3.0790546d+2, 1.3060808d+3, -1.1816427d+3, 3.0805037d+2,
     : 1.3299385d0, -2.6470615d0, -2.2064562d+1, -1.0010581d+2,
     : -2.6581274d+2, 1.2415751d+3, -1.1699258d+3, 3.1562484d+2,
     : 1.0104598d0, -4.1729999d0, -3.0014104d+1, -1.1105444d+2,
     : -2.6610754d+2, 1.3365441d+3, -1.2726015d+3, 3.4360979d+2,
     : 2.3510635d0, 1.3120111d0, -6.7977921d+1, -2.3530372d+2,
     : -2.0318454d+2, 1.7929479d+3, -1.7798422d+3, 4.8276169d+2,
     : 4.5663636d+1, 1.1016273d+2, -3.5251514d+2, -4.3004859d+2,
     : 5.1114474d+1, 2.4991770d+3, -2.6633270d+3, 7.3565789d+2,
     : 6.9314241d+1, 3.8244367d+2, -8.7926018d+2, -3.1058687d+2,
     : 6.9174698d+1, 2.9810887d+3, -3.1869214d+3, 8.7980181d+2,
     : 3.6585189d0, 1.1449795d+1, 2.6409903d+1, -7.9152853d+1,
     : -3.8702291d+2, 9.1225304d+2, -5.5431256d+2, 6.5323704d+1,
     : 4.8335103d0, 1.2295178d+1, 2.7850295d+1, -7.6414052d+1,
     : -4.4554510d+2, 1.0468393d+3, -6.7199228d+2, 1.0160147d+2,
     : 5.1899718d0, 1.1774502d+1, 2.8764865d+1, -6.6170686d+1,
     : -5.6849257d+2, 1.3340759d+3, -9.2791520d+2, 1.8203206d+2,
     : 5.2632774d0, 1.3404097d+1, 2.5551224d+1, -5.2545249d+1,
     : -6.6464661d+2, 1.5521292d+3, -1.1262793d+3, 2.4641433d+2,
     : 3.9056622d0, 1.2462535d+1, 1.9867891d+1, -4.1826302d+1,
     : -6.8959283d+2, 1.6054206d+3, -1.1720120d+3, 2.5970926d+2,
     : 4.6716829d0, 1.5030367d+1, 1.5625498d+1, -6.6293629d+1,
     : -6.5431566d+2, 1.5984864d+3, -1.1571505d+3, 2.4244541d+2,
     : 7.7832976d0, 2.5271562d+1, -1.6785153d+1, -1.8436782d+2,
     : -4.4049156d+2, 1.5352628d+3, -1.1405000d+3, 2.0978015d+2,
     : 1.1426721d+2, 1.9996963d+2, -5.4575393d+2, -2.6955934d+2,
     : 3.8784431d+2, 7.7778304d+2, -7.2177169d+2, 6.6233804d+1,
     : 7.0518441d+1, 1.3427485d+2, -1.2871522d+3, 6.8979888d+2,
     : 7.7949704d+2, -1.7844229d+2, -1.8151720d+2, -7.9395981d+1,
     : 3.6420248d0, 1.1394353d+1, 2.6371208d+1, -7.9127151d+1,
     : -3.8691524d+2, 9.1213973d+2, -5.5422476d+2, 6.5289249d+1,
     : 4.8099114d0, 1.3751787d+1, 1.9056260d+1, -8.4421138d+1,
     : -3.6017943d+2, 9.0156708d+2, -5.6758875d+2, 7.2857305d+1,
     : 4.7912908d0, 8.7285706d0, -3.1035726d0, -7.4827132d+1,
     : -2.8687807d+2, 8.3782644d+2, -5.7383763d+2, 8.5879018d+1,
     : 3.2258215d0, 1.9728719d0, -1.8042495d+1, -4.9626502d+1,
     : -2.2259406d+2, 7.3388899d+2, -5.3779941d+2, 8.7476461d+1,
     : 1.9615223d0, -1.3281181d0, -2.2430720d+1, -2.9551065d+1,
     : -1.9153483d+2, 6.5349779d+2, -4.9227421d+2, 8.0965422d+1,
     : 2.5868559d0, 2.3976470d-1, -2.9624856d+1, -4.2290961d+1,
     : -1.7907994d+2, 6.9235330d+2, -5.3252094d+2, 8.7688188d+1,
     : 1.3394064d+1, 2.4881804d+1, -1.0064405d+2, -1.4917105d+2,
     : 2.0584000d-1, 7.5918286d+2, -6.4961735d+2, 1.0041904d+2,
     : 1.2192309d+2, 1.7694433d+2, -6.3916092d+2, -1.5806332d+2,
     : 6.0785623d+2, 3.6423812d+2, -4.8808372d+2, 2.1529593d+1,
     : 7.0437506d+1, 1.3396735d+2, -1.2873528d+3, 6.9029287d+2,
     : 7.7997990d+2, -1.7908541d+2, -1.8130907d+2, -7.9437403d+1/
      data cr12/
     : 3.0845555d0, 6.3610370d0, 3.8376793d+1, -1.3466819d+2,
     : -3.9028623d+2, 1.1492060d+3, -8.3307438d+2, 1.5891769d+2,
     : -1.0189270d+2, -1.3113916d+2, 3.1427042d+2, -2.8183160d+2,
     : 1.8699857d+2, 1.0546508d+2, -7.8120193d+1, -4.3806474d+1,
     : 2.7788679d+1, 1.1128545d+2, -1.2637841d+2, -3.3662183d+2,
     : 1.1840124d+3, -1.8994549d+3, 1.5591807d+3, -5.0738491d+2,
     : 1.3534281d+1, -3.5519800d+1, -2.4431434d+2, 2.9150547d+2,
     : 1.3268048d+3, -3.3983014d+3, 2.9630655d+3, -9.2138029d+2,
     : -7.6652136d0, -1.0054811d+2, -1.9288018d+2, 5.3036581d+2,
     : 1.1395374d+3, -3.6979124d+3, 3.3850123d+3, -1.0651022d+3,
     : 1.3625011d+1, -2.6246363d+1, -2.0525679d+2, 2.5158000d+2,
     : 1.0738888d+3, -2.8707663d+3, 2.6073245d+3, -8.4654456d+2,
     : 1.0657514d+2, 2.5404875d+2, -4.0969706d+2, -6.5655507d+2,
     : 1.5428162d+3, -1.1994137d+3, 6.1059768d+2, -2.1864182d+2,
     : 6.4176171d+2, 1.5472624d+3, -1.5112082d+3, -2.8212309d+3,
     : 3.0738659d+3, 6.1203807d+2, -1.9111626d+3, 6.3470700d+2,
     : -6.6152106d+3, -1.2616496d+4, 5.2971146d+3, 1.7916998d+4,
     : -1.6214049d+3, -4.4832016d+3, -2.2979954d+3, 1.2737929d+3,
     : 3.0564949d0, 6.2943728d0, 3.8387096d+1, -1.3463212d+2,
     : -3.9024172d+2, 1.1493263d+3, -8.3328048d+2, 1.5897884d+2,
     : 3.5564914d0, 5.7256960d0, 3.1538240d+1, -1.3956755d+2,
     : -3.7805031d+2, 1.1993858d+3, -9.1539896d+2, 1.9083168d+2,
     : 5.8852272d0, 6.2072687d0, 7.1101339d0, -1.4326719d+2,
     : -3.3714827d+2, 1.2792402d+3, -1.0769820d+3, 2.5737736d+2,
     : 4.9405754d0, 2.3325548d0, -1.4528749d+1, -1.2429131d+2,
     : -2.9190569d+2, 1.2853370d+3, -1.1666693d+3, 3.0313669d+2,
     : 2.1499615d0, -3.1504269d0, -2.3369781d+1, -1.0125365d+2,
     : -2.5650206d+2, 1.2312153d+3, -1.1641902d+3, 3.1329755d+2,
     : 1.6480723d0, -7.4649684d0, -3.8109942d+1, -1.1936556d+2,
     : -2.1849799d+2, 1.3266291d+3, -1.3063861d+3, 3.5861713d+2,
     : 3.6999293d0, -3.5464350d0, -1.2710415d+2, -3.0650742d+2,
     : 1.3082726d+2, 1.6723062d+3, -1.9535228d+3, 5.7585558d+2,
     : 1.9728861d+2, 2.1857997d+2, -1.1299328d+3, -4.0335696d+2,
     : 1.5763194d+3, 1.3780336d+3, -2.7544824d+3, 9.2542963d+2,
     : -1.0049328d+2, -9.3588638d+1, -2.5210595d+3, 1.9623618d+3,
     : 1.9525315d+3, 4.1223807d+2, -2.8778864d+3, 1.0850336d+3,
     : 3.1065813d0, 4.8352710d0, 4.1703538d+1, -1.0483330d+2,
     : -3.4238499d+2, 8.5844699d+2, -5.1564295d+2, 5.3128178d+1,
     : 5.8021964d0, 6.3130481d0, 3.8194544d+1, -9.7322478d+1,
     : -4.1128126d+2, 1.0089909d+3, -6.4430289d+2, 9.2455365d+1,
     : 8.6949546d0, 1.1091289d+1, 3.0273756d+1, -7.8694202d+1,
     : -5.5601270d+2, 1.3246502d+3, -9.1785412d+2, 1.7748729d+2,
     : 6.5399795d0, 1.3152698d+1, 2.5367585d+1, -5.4741750d+1,
     : -6.6477115d+2, 1.5499684d+3, -1.1181749d+3, 2.4194914d+2,
     : 4.2692754d0, 1.2885211d+1, 2.0330661d+1, -4.1906656d+1,
     : -6.8449920d+2, 1.5859911d+3, -1.1493078d+3, 2.5081207d+2,
     : 4.9295379d0, 1.3225870d+1, 1.0388170d+1, -6.9907854d+1,
     : -6.1229456d+2, 1.5399170d+3, -1.1163424d+3, 2.2864816d+2,
     : 1.5854048d+1, 3.3654083d+1, -8.3797874d+1, -2.2467899d+2,
     : -1.0259292d+2, 1.1097260d+3, -8.9897509d+2, 1.4792156d+2,
     : 5.0433417d+1, -4.3081756d+2, -1.3257772d+3, 1.4623799d+3,
     : 1.6650192d+3, -2.2340794d+3, 1.0241684d+3, -3.3217467d+2,
     : -7.2700733d+2, -1.8858162d+3, -1.8769361d+3, 6.4519325d+3,
     : 7.1606584d+2, -5.6410907d+3, 3.4225326d+3, -8.9658107d+2,
     : 3.1042564d0, 4.8359895d0, 4.1709914d+1, -1.0488794d+2,
     : -3.4230320d+2, 8.5835071d+2, -5.1556475d+2, 5.3102358d+1,
     : 4.1742987d0, 7.0791637d0, 3.2903337d+1, -1.0763232d+2,
     : -3.2033824d+2, 8.5408461d+2, -5.3341966d+2, 6.1995609d+1,
     : 6.6165591d0, 6.7881364d0, 2.0984081d0, -9.1403856d+1,
     : -2.5650549d+2, 8.0046690d+2, -5.4558003d+2, 7.6389789d+1,
     : 4.6154124d0, 1.0107935d0, -1.7388021d+1, -5.3485900d+1,
     : -2.0672974d+2, 7.0282454d+2, -5.0942758d+2, 7.7410602d+1,
     : 2.9116997d0, -1.7554732d0, -2.2946294d+1, -2.9408660d+1,
     : -1.7776842d+2, 6.1703868d+2, -4.5627142d+2, 6.7892066d+1,
     : 3.8124732d0, -1.8019987d0, -3.6754673d+1, -4.7108852d+1,
     : -1.1816307d+2, 6.0155885d+2, -4.7030916d+2, 6.8338395d+1,
     : 3.6500655d+1, 4.5767068d+1, -2.3185400d+2, -1.6362733d+2,
     : 4.3230637d+2, 1.8451429d+2, -3.2210947d+2, 2.0562178d+1,
     : 1.7652811d+1, -5.8534513d+2, -1.4051722d+3, 1.8522593d+3,
     : 1.8312807d+3, -2.8270712d+3, 1.3690747d+3, -3.9836280d+2,
     : -7.2733342d+2, -1.8867133d+3, -1.8767839d+3, 6.4537231d+3,
     : 7.1618176d+2, -5.6427974d+3, 3.4233752d+3, -8.9669577d+2/
      data cr14/
     : -1.0657428d+1, -1.7012710d+1, 8.7807337d+1, -1.8212988d+2,
     : -2.2351768d+2, 8.4683779d+2, -5.9918731d+2, 9.1883444d+1,
     : -6.9891632d+1, -3.2945312d+1, 2.3949825d+2, -3.9685651d+2,
     : 3.5980134d+2, -1.4259458d+2, 1.3984712d+2, -1.0998307d+2,
     : 3.5853782d+1, 1.1197743d+2, -1.6682174d+2, -2.8435991d+2,
     : 1.2242693d+3, -2.0734430d+3, 1.7243033d+3, -5.5922558d+2,
     : 1.1489201d+1, -4.3307860d+1, -2.4063378d+2, 3.2255677d+2,
     : 1.2985497d+3, -3.4294853d+3, 3.0185088d+3, -9.4314761d+2,
     : -6.1113328d0, -9.5217132d+1, -1.9519884d+2, 5.0707320d+2,
     : 1.1402293d+3, -3.6382162d+3, 3.3297822d+3, -1.0513651d+3,
     : 2.2677930d+1, -1.2361181d+1, -2.5563477d+2, 1.9133185d+2,
     : 1.2138762d+3, -2.8255185d+3, 2.4481847d+3, -7.8494168d+2,
     : 2.1787942d+2, 3.7917917d+2, -8.9111149d+2, -8.2428182d+2,
     : 2.5434926d+3, -1.6765051d+3, 3.1417401d+2, -1.9683460d+1,
     : 4.0085960d+2, -9.5626948d+2, -4.2700367d+3, 2.8914835d+3,
     : 6.9762872d+3, -5.5940239d+3, -6.6399901d+2, 9.0940281d+2,
     : -1.6226771d+3, -1.3555769d+3, -4.4502316d+3, 1.0639020d+4,
     : 2.3588635d+3, -7.9242340d+3, 9.0118674d+2, 9.3014462d+2,
     : -1.0708893d+1, -1.7118343d+1, 8.7854353d+1, -1.8203146d+2,
     : -2.2345674d+2, 8.4692290d+2, -5.9943325d+2, 9.1967644d+1,
     : -7.1983984d0, -1.5406498d+1, 8.0400125d+1, -1.9071049d+2,
     : -2.3489607d+2, 9.5318855d+2, -7.2780147d+2, 1.3747058d+2,
     : 1.2061830d+1, -1.9276408d0, 2.5409393d+1, -1.9120261d+2,
     : -2.4408025d+2, 1.1537386d+3, -9.8698991d+2, 2.3219250d+2,
     : 2.1164366d+1, 1.1561150d+1, -2.5020619d+1, -1.5766326d+2,
     : -2.5904138d+2, 1.2644419d+3, -1.1506260d+3, 2.9767586d+2,
     : 8.0825177d0, 7.5812274d-1, -2.8818518d+1, -1.1185609d+2,
     : -2.5099846d+2, 1.2371466d+3, -1.1668365d+3, 3.1216353d+2,
     : 8.0301953d0, -8.4083381d0, -5.3709615d+1, -1.3428649d+2,
     : -1.5999866d+2, 1.3285009d+3, -1.3669340d+3, 3.8519260d+2,
     : 1.7331232d+1, 9.7398317d0, -2.6456145d+2, -4.2859276d+2,
     : 7.9531192d+2, 1.3369678d+3, -2.2276065d+3, 7.5705336d+2,
     : -1.7819168d+2, -1.8073242d+3, -2.5924052d+3, 4.1223603d+3,
     : 4.3270274d+3, -3.8500602d+3, -1.5896244d+3, 1.1845299d+3,
     : -4.5310683d+3, -7.5713481d+3, -6.8133540d+2, 2.0151510d+4,
     : -1.3552018d+3, -1.0295065d+4, 1.5657477d+3, 9.8038914d+2,
     : -1.8673386d+1, -4.2862120d+1, 1.1961222d+2, -1.4404870d+2,
     : -2.6418461d+2, 7.7136403d+2, -4.7479855d+2, 4.3820555d+1,
     : -3.4459789d0, -3.3500449d+1, 9.3250891d+1, -1.2929028d+2,
     : -3.5079709d+2, 9.4839808d+2, -6.1731987d+2, 8.6110244d+1,
     : 3.7160143d+1, 2.2864127d+1, 1.4871296d+1, -1.3231846d+2,
     : -5.1718126d+2, 1.3204563d+3, -9.1450325d+2, 1.7502170d+2,
     : 2.2505295d+1, 2.6753386d+1, 1.0524523d+1, -8.0023132d+1,
     : -6.5532486d+2, 1.5547237d+3, -1.1131368d+3, 2.3784287d+2,
     : 6.0706463d0, 1.3982697d+1, 1.9506537d+1, -4.3324850d+1,
     : -6.7686861d+2, 1.5594001d+3, -1.1185405d+3, 2.3896918d+2,
     : 6.7865970d0, 1.1150954d+1, 1.9278645d0, -6.7183226d+1,
     : -5.6063756d+2, 1.4441546d+3, -1.0421108d+3, 2.0476218d+2,
     : 4.2338314d+1, 1.5867988d+1, -3.1387384d+2, -9.9612792d+1,
     : 5.8539054d+2, -4.4134215d0, -2.1238997d+2, -2.0709060d+1,
     : -1.0048242d+3, -3.2388960d+3, 3.5053824d+2, 8.6142088d+3,
     : -1.1016910d+3, -9.3964832d+3, 7.2906303d+3, -1.8694708d+3,
     : -4.4638834d+3, -5.0957870d+3, 5.7795335d+3, 1.9395845d+4,
     : -1.4144574d+4, -1.3141853d+4, 1.5390687d+4, -4.2694288d+3,
     : -1.8628983d+1, -4.2727214d+1, 1.1963021d+2, -1.4430871d+2,
     : -2.6410266d+2, 7.7134563d+2, -4.7474925d+2, 4.3803316d+1,
     : -7.6894995d0, -2.5067727d+1, 9.5263788d+1, -1.6085558d+2,
     : -2.4647976d+2, 7.8583078d+2, -5.0090967d+2, 5.4052039d+1,
     : 1.6974700d+1, -8.1445234d-2, 1.5721105d+1, -1.4050750d+2,
     : -1.9605727d+2, 7.5611863d+2, -5.2130417d+2, 6.9331670d+1,
     : 2.1502310d+1, 1.2677192d+1, -2.8698069d+1, -8.9252841d+1,
     : -1.7585617d+2, 6.8121903d+2, -4.8667241d+2, 6.8445387d+1,
     : 1.0425845d+1, 3.1758589d0, -2.8625909d+1, -4.4460215d+1,
     : -1.5936321d+2, 5.8842105d+2, -4.2180688d+2, 5.3737887d+1,
     : 9.0777456d0, -5.0737862d0, -4.6256387d+1, -6.2481677d+1,
     : -2.7450851d+1, 4.7059364d+2, -3.7780866d+2, 3.9573425d+1,
     : 5.9788567d+1, -6.7629423d+1, -5.8583221d+2, 2.3609512d+2,
     : 1.2387507d+3, -1.2586346d+3, 5.3548858d+2, -1.8038703d+2,
     : -1.1400997d+3, -3.5415928d+3, 6.1411019d+2, 9.3304215d+3,
     : -1.4325427d+3, -1.0071480d+4, 7.8539944d+3, -1.9899077d+3,
     : -4.4944040d+3, -5.1548667d+3, 5.8326550d+3, 1.9497980d+4,
     : -1.4193444d+4, -1.3187249d+4, 1.5413600d+4, -4.2707663d+3/
      data alr7/
     : -1.8078918d+3, -4.7787003d+3, -4.0523869d+3, -4.1221779d+3,
     : -4.5809200d+3, -4.4992434d+3, -4.3311400d+3, -5.8568855d+3,
     : -4.9197514d+3, -1.7981706d+3, -3.6560670d+4, -4.1063414d+3,
     : -1.2435703d+3, -7.5142806d+2, -7.8914653d+2, -1.7531561d+3,
     : -1.8435639d+4, -4.8774321d+3, -2.8838164d+3, -2.6054783d+3,
     : -1.9803714d+3, -1.4624994d+3, -1.3059294d+3, -1.7938132d+3,
     : -3.1839456d+3, -5.3742539d+3, -6.7060703d+3, -2.8838164d+3,
     : -1.6918226d+4, -2.4948883d+3, -9.5854189d+2, -6.5120351d+2,
     : -6.8152373d+2, -1.3542953d+3, -9.9807125d+3, -6.7060703d+3/
      data alr8/
     : -1.8197324d+3, -2.7223096d+3, -6.9185348d+3, -1.6665006d+4,
     : -2.6101065d+4, -2.2174728d+4, -1.2065267d+4, -6.6732176d+3,
     : -5.3074891d+3, -1.7872942d+3, -1.6633443d+3, -1.3149911d+3,
     : -9.9682252d+2, -8.5414688d+2, -1.0294238d+3, -1.9226106d+3,
     : -3.9061792d+3, -5.2510102d+3, -2.9738586d+3, -3.3255772d+3,
     : -2.0361352d+3, -1.5269168d+3, -1.3654844d+3, -2.1166521d+3,
     : -2.8122490d+3, -8.6677989d+3, -8.4801199d+3, -2.9951511d+3,
     : -2.9413432d+3, -2.8340742d+3, -2.6254366d+3, -2.5015653d+3,
     : -2.7044901d+3, -3.9477626d+3, -6.6205269d+3, -8.4133147d+3/
      data alr9/
     : -1.9531827d+3, -2.9301105d+3, -7.2453496d+3, -1.7059968d+4,
     : -2.5574475d+4, -2.0938847d+4, -1.1470970d+4, -6.7845188d+3,
     : -5.6035173d+3, -1.9342807d+3, -1.7771669d+3, -1.3739437d+3,
     : -1.0342129d+3, -8.7746794d+2, -1.0327227d+3, -1.9714148d+3,
     : -4.0773953d+3, -5.5564710d+3, -3.1202700d+3, -3.2280982d+3,
     : -2.0866334d+3, -1.5605212d+3, -1.4811253d+3, -2.5259584d+3,
     : -3.4254766d+3, -7.2922651d+3, -1.1665132d+4, -3.1043615d+3,
     : -3.0881710d+3, -2.9370249d+3, -2.7212348d+3, -2.5775995d+3,
     : -2.8864130d+3, -4.5730071d+3, -8.6638864d+3, -1.1703815d+4/
      data alr1/
     : -1.9353618d+3, -3.8083869d+3, -8.8525421d+3, -1.9663260d+4,
     : -2.0864990d+4, -1.6318948d+4, -8.7935734d+3, -5.3296668d+3,
     : -4.5018167d+3, -1.9188040d+3, -1.9315823d+3, -1.4532125d+3,
     : -1.0564479d+3, -8.9582665d+2, -1.0424547d+3, -1.8341370d+3,
     : -3.0153203d+3, -4.4841111d+3, -2.9124901d+3, -3.4345225d+3,
     : -2.6894224d+3, -2.0427689d+3, -1.4134219d+3, -2.4568414d+3,
     : -4.4781463d+3, -9.9699278d+3, -1.7031921d+4, -2.8814031d+3,
     : -3.2094104d+3, -3.0609324d+3, -2.8242593d+3, -2.7552878d+3,
     : -3.1319312d+3, -5.5036219d+3, -1.0558422d+4, -1.7031921d+4/
      data alr12/
     : -2.3831340d+3, -3.5109027d+3, -8.1803226d+3, -1.7249582d+4,
     : -2.3419088d+4, -1.6323773d+4, -7.2872276d+3, -3.5501928d+3,
     : -2.6992586d+3, -2.3726472d+3, -2.1035301d+3, -1.5171472d+3,
     : -1.0978149d+3, -9.3486498d+2, -1.0439041d+3, -1.5029176d+3,
     : -2.2594154d+3, -2.6953321d+3, -3.3928482d+3, -2.9766455d+3,
     : -2.2718962d+3, -1.7511999d+3, -1.7426150d+3, -2.9407375d+3,
     : -5.9516012d+3, -1.5229427d+4, -2.7551271d+4, -3.3567784d+3,
     : -3.3312921d+3, -3.1391385d+3, -2.9539382d+3, -2.9192873d+3,
     : -3.4099183d+3, -6.5867097d+3, -1.7321447d+4, -2.7551271d+4/
      data alr14/
     : -2.7805357d+3, -4.0316430d+3, -8.8564929d+3, -1.7755732d+4,
     : -2.2212756d+4, -1.3078100d+4, -3.5334904d+3, -5.8434129d+2,
     : -2.0117585d+2, -2.7684154d+3, -2.3575220d+3, -1.6011425d+3,
     : -1.1215457d+3, -9.7758648d+2, -9.7979304d+2, -7.2209318d+2,
     : -3.3683624d+2, -2.0180959d+2, -3.4432009d+3, -3.0519060d+3,
     : -2.3281624d+3, -1.8061020d+3, -1.8519186d+3, -3.1421095d+3,
     : -7.7456170d+3, -2.5474842d+4, -5.2668679d+4, -3.4637778d+3,
     : -3.3473248d+3, -3.1585397d+3, -3.0354433d+3, -3.0969790d+3,
     : -3.7995790d+3, -8.1228070d+3, -2.7826842d+4, -5.2668679d+4/
      data alphlr7/
     : -6.3461068d-1, -7.1670848d-1, -6.7715566d-1, -6.6642614d-1,
     : -6.7172112d-1, -6.6530524d-1, -6.5873708d-1, -6.9912558d-1,
     : -7.0995430d-1, -6.3382597d-1, -8.8457745d-1, -5.7892604d-1,
     : -4.2194151d-1, -3.5797540d-1, -3.6360276d-1, -4.6190790d-1,
     : -7.6371114d-1, -7.0872569d-1, -6.8410478d-1, -6.7540274d-1,
     : -6.5143669d-1, -6.2530791d-1, -6.1529080d-1, -6.4223383d-1,
     : -6.8704029d-1, -7.2585450d-1, -7.4250408d-1, -6.8410478d-1,
     : -8.1526032d-1, -5.5326868d-1, -4.2836501d-1, -3.7944046d-1,
     : -3.8413431d-1, -4.6584053d-1, -7.1585775d-1, -7.4250408d-1/
      data alphlr8/
     : -6.3096387d-1, -6.7536175d-1, -7.7935438d-1, -8.7721172d-1,
     : -9.2511247d-1, -8.9853879d-1, -8.1458037d-1, -7.3136839d-1,
     : -6.9870977d-1, -6.2860866d-1, -6.2026726d-1, -5.9415611d-1,
     : -5.6516622d-1, -5.5055732d-1, -5.6713034d-1, -6.1882930d-1,
     : -6.7466444d-1, -6.9718351d-1, -6.8289068d-1, -6.9795874d-1,
     : -6.4782091d-1, -6.2473644d-1, -6.1558895d-1, -6.4847474d-1,
     : -6.5206310d-1, -7.6090741d-1, -7.4799498d-1, -6.8368339d-1,
     : -6.8062746d-1, -6.7529649d-1, -6.6731404d-1, -6.6367472d-1,
     : -6.6856837d-1, -6.9445866d-1, -7.3024735d-1, -7.4700635d-1/
      data alphlr9/
     : -6.3223843d-1, -6.7713464d-1, -7.7856939d-1, -8.7457228d-1,
     : -9.1719258d-1, -8.8370016d-1, -7.9460688d-1, -7.1222919d-1,
     : -6.8080642d-1, -6.3082172d-1, -6.2124121d-1, -5.9298409d-1,
     : -5.6380220d-1, -5.4762062d-1, -5.5877012d-1, -6.0700537d-1,
     : -6.5817043d-1, -6.7959739d-1, -6.8195721d-1, -6.8857051d-1,
     : -6.4563620d-1, -6.2223367d-1, -6.1876688d-1, -6.6081180d-1,
     : -6.5860336d-1, -7.1311457d-1, -7.5773476d-1, -6.8122454d-1,
     : -6.7982352d-1, -6.7327166d-1, -6.6560543d-1, -6.6072821d-1,
     : -6.6689523d-1, -6.9543029d-1, -7.3752233d-1, -7.5810261d-1/
      data alphlr1/
     : -6.1956378d-1, -6.9878894d-1, -7.9377549d-1, -8.8388731d-1,
     : -8.8360989d-1, -8.4198007d-1, -7.4448668d-1, -6.5763208d-1,
     : -6.2559069d-1, -6.1830634d-1, -6.2304549d-1, -5.9268825d-1,
     : -5.5982432d-1, -5.4280509d-1, -5.4901328d-1, -5.8087485d-1,
     : -5.9669594d-1, -6.2501532d-1, -6.6317218d-1, -6.8746535d-1,
     : -6.6845457d-1, -6.4670574d-1, -6.0164532d-1, -6.4382211d-1,
     : -6.6818056d-1, -7.1785544d-1, -7.6528049d-1, -6.6183080d-1,
     : -6.7713570d-1, -6.7156611d-1, -6.6354671d-1, -6.6126350d-1,
     : -6.6486766d-1, -6.9649727d-1, -7.2851432d-1, -7.6528049d-1/
      data alphlr12/
     : -6.4178266d-1, -6.8498387d-1, -7.8078967d-1, -8.6507084d-1,
     : -8.9553630d-1, -8.3770625d-1, -7.1313119d-1, -5.9561631d-1,
     : -5.4924682d-1, -6.4114240d-1, -6.2806651d-1, -5.9342563d-1,
     : -5.6042256d-1, -5.4288412d-1, -5.4139246d-1, -5.4535761d-1,
     : -5.4789811d-1, -5.4902737d-1, -6.7968803d-1, -6.6754910d-1,
     : -6.4571639d-1, -6.2563183d-1, -6.2438032d-1, -6.5871702d-1,
     : -6.8741181d-1, -7.4383021d-1, -7.9288315d-1, -6.7835202d-1,
     : -6.7706104d-1, -6.7031207d-1, -6.6459324d-1, -6.6268797d-1,
     : -6.6578081d-1, -7.0060063d-1, -7.6166531d-1, -7.9288315d-1/
      data alphlr14/
     : -6.5565952d-1, -6.9708678d-1, -7.8614859d-1, -8.6492621d-1,
     : -8.8538903d-1, -8.0564809d-1, -6.2025305d-1, -3.7916165d-1,
     : -2.4380289d-1, -6.5502822d-1, -6.3761497d-1, -5.9669541d-1,
     : -5.6000926d-1, -5.4352755d-1, -5.2630474d-1, -4.5089187d-1,
     : -3.2028373d-1, -2.4415236d-1, -6.7868276d-1, -6.6806962d-1,
     : -6.4601033d-1, -6.2592187d-1, -6.2598690d-1, -6.5669259d-1,
     : -6.9979172d-1, -7.7350849d-1, -8.3136823d-1, -6.7934479d-1,
     : -6.7482206d-1, -6.6822786d-1, -6.6467786d-1, -6.6461087d-1,
     : -6.6854906d-1, -7.0538724d-1, -7.8545840d-1, -8.3136823d-1/
* coefficients for d0 rotation matrices
* stored (by column) for each of 9 angles (0:22.5:180) and for l=0-8

      data d0 /
     : 1.d+0, 1.d+0, 1.d+0, 1.d+0, 1.d+0, 1.d+0, 1.d+0, 1.d+0, 1.d+0,
     : 1.d+0, 9.2387953d-1, 7.0710679d-1, 3.8268344d-1, 1.3349124d-8,
     : -3.8268342d-1, -7.0710677d-1, -9.2387952d-1, -1.d+0, 1.d+0,
     : 7.8033009d-1, 2.5000001d-1, -2.8033008d-1, -5.d-1, -2.8033010d-1,
     : 2.4999997d-1, 7.8033006d-1, 1.d+0, 1.d+0, 5.8563198d-1,
     : -1.7677668d-1, -4.3391842d-1, -2.0023687d-8, 4.3391841d-1,
     : 1.7677673d-1, -5.8563193d-1, -1.d+0, 1.d+0, 3.6159588d-1,
     : -4.0625000d-1, -8.0345887d-2, 3.7500000d-1, -8.0345840d-2,
     : -4.0625001d-1, 3.6159581d-1, 1.d+0, 1.d+0, 1.3282228d-1,
     : -3.7565048d-1, 2.9179007d-1, 2.5029608d-8, -2.9179009d-1,
     : 3.7565046d-1, -1.3282219d-1, -1.d+0, 1.d+0, -7.6358299d-2,
     : -1.4843752d-1, 2.7167082d-1, -3.1250000d-1, 2.7167079d-1,
     : -1.4843745d-1, -7.6358384d-2, 1.d+0, 1.d+0, -2.4486142d-1,
     : 1.2705823d-1, -5.7029911d-2, -2.9201210d-8, 5.7029970d-2,
     : -1.2705830d-1, 2.4486150d-1, -1.d+0, 1.d+0, -3.5735359d-1,
     : 2.9833984d-1, -2.7863272d-1, 2.7343750d-1, -2.7863274d-1,
     : 2.9833986d-1, -3.5735364d-1, 1.d+0/

* coefficients for d20 rotation matrices
* stored (by column) for each of 7 angles (22:5:22.5:157.5) and for l=2-8
      data d2 /
     : 8.9679867d-2, 3.0618622d-1, 5.2269257d-1, 6.1237244d-1,
     : 5.2269257d-1, 3.0618622d-1, 8.9679867d-2, 1.8526582d-1,
     : 4.8412292d-1, 4.4727126d-1, -0.d+0, -4.4727126d-1, -4.8412292d-1,
     : -1.8526582d-1, 2.8798601d-1, 4.9410588d-1, 8.4775167d-3,
     : -3.9528471d-1, 8.4775167d-3, 4.9410588d-1, 2.8798601d-1,
     : 3.8249228d-1, 3.2021721d-1, -3.3173380d-1, 0.d+0, 3.3173380d-1,
     : -3.2021721d-1, -3.8249228d-1, 4.5386126d-1, 4.0027151d-2,
     : -2.5372550d-1, 3.2021721d-1, -2.5372550d-1, 4.0027151d-2,
     : 4.5386126d-1, 4.9005182d-1, -2.1518084d-1, 9.1576621d-2, -0.d+0,
     : -9.1576621d-2, 2.1518084d-1, -4.9005182d-1, 4.8368899d-1,
     : -3.2931303d-1, 2.8759680d-1, -2.7731624d-1, 2.8759680d-1,
     : -3.2931303d-1, 4.8368899d-1/

* check if desired values or r and R are outside of range
* if R .lt. 3 bohr, the potential are set equal to their values at R=3
* if 1.4<r or r>2.7, then the interaction potential is taken equal to its
* value at these limits
* NOTE that  the calculated OH potential at the chosen
* value of r is added at the end


      if (rr.lt.3) then
         rbig=3d0
      else
         rbig=rr
      endif
      if (r.lt.1.4d0) then
         rsm=1.4d0
      elseif (r.gt.2.7d0) then
         rsm=2.7d0
      else
         rsm=r
      endif

* determine potentials for each state at each of grid points in roh and gamma
      xrr=1-exp(-(rbig-rro)/alphrr)
      switch=half*(one+tanh(rbig-8.5d0))
      ir=3
        call dcopy(288,cr9(1,1),1,cr(1,1),1)
        call dcopy(36,alphlr9(1,1),1,alphlr(1,1),1)
        call dcopy(36,alr9(1,1),1,alr(1,1),1)
        do igam=1,9
            nlow=(igam-1)*8
            do istate=1,4
               vpoly=polyval(cr(nlow+1,istate),xrr,7)
               vexp=alr(igam,istate)*exp(alphlr(igam,istate)*rbig)
               v(ir,igam,istate)=(one-switch)*vpoly+switch*vexp
            enddo
         enddo
* now setup matrix for least squares fit in the angle gamma
      if (ifirst.eq.0) then
* first for fit of vsum in legendre polynomials
         call dcopy(81,d0,1,ag0,1)
         call dqrank(ag0,9,9,9,tol,kg0,kpvtg0,qrauxg0,work)
* then for fit of vdif in d20 reduced matrix elements
         call dcopy(49,d2,1,ag2,1)
         call dqrank(ag2,7,7,7,tol,kg2,kpvtg2,qrauxg2,work)
      endif
* now determine each of the potentials at the input value of roh and all value
      do igam=1,9
         do istate=1,4
            vgamma(istate)=v(3,igam,istate)
         enddo
*  determine vsum and vdif for both the a' and a" pes's
         do imult=1,2
            ind=(imult-1)*2
            vsum(igam,imult)=0.5*(vgamma(ind+1)+vgamma(ind+2))
            vdif(igam,imult)=0.5*(-vgamma(ind+1)+vgamma(ind+2))
         enddo
      enddo
      do imult=2,2
* now fit vsum to expansion in legendre polynomials
         call dcopy(9,vsum(1,imult),1,vgam,1)
         call dqrlss(ag0,9,9,9,kg0,vgam,xgam,rsd,kpvtg0,qrauxg0)
         call dcopy(9,xgam,1,xgam0(1,imult),1)
* xgam0 contains the coefficients
* now fit vdif to expansion in reduced rotation matrix elements
         call dcopy(7,vdif(2,imult),1,vgam,1)
         call dqrlss(ag2,7,7,7,kg2,vgam,xgam,rsd,kpvtg2,qrauxg2)
         call dcopy(7,xgam,1,xgam2(1,imult),1)
      enddo
* xgam2 contains the coefficients
* transform expansion coefficients into hartree
      call dscal(9,tohar,xgam0(1,2),1)
      call dscal(7,tohar,xgam2(1,2),1)
* copy expansion coefficients into vv0 and vvl
      vv0=xgam0(1,2)
      call dcopy(8,xgam0(2,2),1,vvl(1),1)
      call dcopy(7,xgam2(1,2),1,vvl(9),1)
      ifirst=1
      return
      end


      function polyval(c,x,n)
* to evaluate a polynomial of degree n in the variable x
* this uses the reverse ordering of matlab
* sum(i,0:n) c(n-i)*x^i
      implicit double precision (a-h,o-z)
      dimension c(1)
      polyval=c(n+1)
*     print *,polyval
      if (n.eq.1) return
      xx=x
      do i=2,n+1
         polyval=polyval+c(n-i+2)*xx
*        print *,n,i,xx,c(n-i+2),polyval
         xx=xx*x
      enddo
      return
      end
cstart none
c;      function voh(roh)
c;* to evaluate the OH (avqz mrci) potential
c;      implicit double precision (a-h,o-z)
c;      dimension coh(7)
c;      data re,alph /1.8351666870d0,2d0/
c;      data coh /
c;     : 1.3800931d+5, -2.5168803d+5,  2.7423994d+5, -3.1755326d+5,
c;     : 2.1907988d+5, -5.9144536d+1,  5.7660932d-1/
c;      xoh=1-exp(-(roh-re)/alph)
c;*     print *, roh,xoh
c;      voh=polyval(coh,xoh,6)
c;      return
c;      end
c;*-----------
c;      subroutine plm(m,lmax,theta,p,incp)
c;c
c;c  generates alexander-legendre polynomials for m.le.l.le.lmax
c;c
c;      implicit double precision (a-h,o-z)
c;      dimension p(1)
c;      data zero, one,  two,        rad
c;     :     /0.d0, 1.d0, 2.d0, 57.29577951308232d0/
c;      x=cos(theta/rad)
c;      ll = m*incp + 1
c;      if (m.ge.0) go to 1
c;      write (6,100)
c;100   format('  NEGATIVE M IN LEGENDRE ROUTINE:  ABORT')
c;      call exit
c;1     if (m.gt.0) go to 5
c;c  here for regular legendre polynomials
c;      p(ll)=one
c;      ll=ll+incp
c;      pm1=one
c;      pm2=zero
c;      do 2 l=1,lmax
c;      pp=((two*l-one)*x*pm1-(l-one)*pm2)/dble(l)
c;      p(ll)=pp
c;      ll=ll+incp
c;      pm2=pm1
c;2     pm1=pp
c;      return
c;c
c;c  here for alexander-legendre polynomials
c;c
c;5     imax=2*m
c;      rat=one
c;      do 6 i=2,imax,2
c;      ai=i
c;6     rat=rat*((ai-one)/ai)
c;      y=sin(theta/rad)
c;      pm1=sqrt(rat)*(y**m)
c;      p(ll)=pm1
c;      ll=ll+incp
c;      pm2=zero
c;      low=m+1
c;      if (low.ge.lmax) return
c;      do 10 l=low,lmax-1
c;      al=(l+m)*(l-m)
c;      al=one/al
c;      al2=((l+m-1)*(l-m-1))*al
c;      al=sqrt(al)
c;      al2=sqrt(al2)
c;      pp=(two*l-one)*x*pm1*al-pm2*al2
c;      p(ll)=pp
c;      ll=ll+incp
c;      pm2=pm1
c;10    pm1=pp
c;      return
c;      end
cend
